
'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from .....ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from .....google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from .....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eibc/core/client/v1/query.proto\x12\x12ibc.core.client.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1fibc/core/client/v1/client.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x14gogoproto/gogo.proto",\n\x17QueryClientStateRequest\x12\x11\n\tclient_id\x18\x01 \x01(\t"\x8d\x01\n\x18QueryClientStateResponse\x12*\n\x0cclient_state\x18\x01 \x01(\x0b2\x14.google.protobuf.Any\x12\r\n\x05proof\x18\x02 \x01(\x0c\x126\n\x0cproof_height\x18\x03 \x01(\x0b2\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00"V\n\x18QueryClientStatesRequest\x12:\n\npagination\x18\x01 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"\xba\x01\n\x19QueryClientStatesResponse\x12`\n\rclient_states\x18\x01 \x03(\x0b2).ibc.core.client.v1.IdentifiedClientStateB\x1e\xc8\xde\x1f\x00\xaa\xdf\x1f\x16IdentifiedClientStates\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"x\n\x1aQueryConsensusStateRequest\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x17\n\x0frevision_number\x18\x02 \x01(\x04\x12\x17\n\x0frevision_height\x18\x03 \x01(\x04\x12\x15\n\rlatest_height\x18\x04 \x01(\x08"\x93\x01\n\x1bQueryConsensusStateResponse\x12-\n\x0fconsensus_state\x18\x01 \x01(\x0b2\x14.google.protobuf.Any\x12\r\n\x05proof\x18\x02 \x01(\x0c\x126\n\x0cproof_height\x18\x03 \x01(\x0b2\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00"l\n\x1bQueryConsensusStatesRequest\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"\xa9\x01\n\x1cQueryConsensusStatesResponse\x12L\n\x10consensus_states\x18\x01 \x03(\x0b2,.ibc.core.client.v1.ConsensusStateWithHeightB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"-\n\x18QueryClientStatusRequest\x12\x11\n\tclient_id\x18\x01 \x01(\t"+\n\x19QueryClientStatusResponse\x12\x0e\n\x06status\x18\x01 \x01(\t"\x1a\n\x18QueryClientParamsRequest"G\n\x19QueryClientParamsResponse\x12*\n\x06params\x18\x01 \x01(\x0b2\x1a.ibc.core.client.v1.Params"!\n\x1fQueryUpgradedClientStateRequest"W\n QueryUpgradedClientStateResponse\x123\n\x15upgraded_client_state\x18\x01 \x01(\x0b2\x14.google.protobuf.Any"$\n"QueryUpgradedConsensusStateRequest"]\n#QueryUpgradedConsensusStateResponse\x126\n\x18upgraded_consensus_state\x18\x01 \x01(\x0b2\x14.google.protobuf.Any2\x81\x0b\n\x05Query\x12\x9f\x01\n\x0bClientState\x12+.ibc.core.client.v1.QueryClientStateRequest\x1a,.ibc.core.client.v1.QueryClientStateResponse"5\x82\xd3\xe4\x93\x02/\x12-/ibc/core/client/v1/client_states/{client_id}\x12\x96\x01\n\x0cClientStates\x12,.ibc.core.client.v1.QueryClientStatesRequest\x1a-.ibc.core.client.v1.QueryClientStatesResponse")\x82\xd3\xe4\x93\x02#\x12!/ibc/core/client/v1/client_states\x12\xdf\x01\n\x0eConsensusState\x12..ibc.core.client.v1.QueryConsensusStateRequest\x1a/.ibc.core.client.v1.QueryConsensusStateResponse"l\x82\xd3\xe4\x93\x02f\x12d/ibc/core/client/v1/consensus_states/{client_id}/revision/{revision_number}/height/{revision_height}\x12\xae\x01\n\x0fConsensusStates\x12/.ibc.core.client.v1.QueryConsensusStatesRequest\x1a0.ibc.core.client.v1.QueryConsensusStatesResponse"8\x82\xd3\xe4\x93\x022\x120/ibc/core/client/v1/consensus_states/{client_id}\x12\xa2\x01\n\x0cClientStatus\x12,.ibc.core.client.v1.QueryClientStatusRequest\x1a-.ibc.core.client.v1.QueryClientStatusResponse"5\x82\xd3\xe4\x93\x02/\x12-/ibc/core/client/v1/client_status/{client_id}\x12\x8a\x01\n\x0cClientParams\x12,.ibc.core.client.v1.QueryClientParamsRequest\x1a-.ibc.core.client.v1.QueryClientParamsResponse"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/ibc/client/v1/params\x12\xb4\x01\n\x13UpgradedClientState\x123.ibc.core.client.v1.QueryUpgradedClientStateRequest\x1a4.ibc.core.client.v1.QueryUpgradedClientStateResponse"2\x82\xd3\xe4\x93\x02,\x12*/ibc/core/client/v1/upgraded_client_states\x12\xc0\x01\n\x16UpgradedConsensusState\x126.ibc.core.client.v1.QueryUpgradedConsensusStateRequest\x1a7.ibc.core.client.v1.QueryUpgradedConsensusStateResponse"5\x82\xd3\xe4\x93\x02/\x12-/ibc/core/client/v1/upgraded_consensus_statesB:Z8github.com/cosmos/ibc-go/v3/modules/core/02-client/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.client.v1.query_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z8github.com/cosmos/ibc-go/v3/modules/core/02-client/types'
    _QUERYCLIENTSTATERESPONSE.fields_by_name['proof_height']._options = None
    _QUERYCLIENTSTATERESPONSE.fields_by_name['proof_height']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYCLIENTSTATESRESPONSE.fields_by_name['client_states']._options = None
    _QUERYCLIENTSTATESRESPONSE.fields_by_name['client_states']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f\x16IdentifiedClientStates'
    _QUERYCONSENSUSSTATERESPONSE.fields_by_name['proof_height']._options = None
    _QUERYCONSENSUSSTATERESPONSE.fields_by_name['proof_height']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYCONSENSUSSTATESRESPONSE.fields_by_name['consensus_states']._options = None
    _QUERYCONSENSUSSTATESRESPONSE.fields_by_name['consensus_states']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERY.methods_by_name['ClientState']._options = None
    _QUERY.methods_by_name['ClientState']._serialized_options = b'\x82\xd3\xe4\x93\x02/\x12-/ibc/core/client/v1/client_states/{client_id}'
    _QUERY.methods_by_name['ClientStates']._options = None
    _QUERY.methods_by_name['ClientStates']._serialized_options = b'\x82\xd3\xe4\x93\x02#\x12!/ibc/core/client/v1/client_states'
    _QUERY.methods_by_name['ConsensusState']._options = None
    _QUERY.methods_by_name['ConsensusState']._serialized_options = b'\x82\xd3\xe4\x93\x02f\x12d/ibc/core/client/v1/consensus_states/{client_id}/revision/{revision_number}/height/{revision_height}'
    _QUERY.methods_by_name['ConsensusStates']._options = None
    _QUERY.methods_by_name['ConsensusStates']._serialized_options = b'\x82\xd3\xe4\x93\x022\x120/ibc/core/client/v1/consensus_states/{client_id}'
    _QUERY.methods_by_name['ClientStatus']._options = None
    _QUERY.methods_by_name['ClientStatus']._serialized_options = b'\x82\xd3\xe4\x93\x02/\x12-/ibc/core/client/v1/client_status/{client_id}'
    _QUERY.methods_by_name['ClientParams']._options = None
    _QUERY.methods_by_name['ClientParams']._serialized_options = b'\x82\xd3\xe4\x93\x02\x17\x12\x15/ibc/client/v1/params'
    _QUERY.methods_by_name['UpgradedClientState']._options = None
    _QUERY.methods_by_name['UpgradedClientState']._serialized_options = b'\x82\xd3\xe4\x93\x02,\x12*/ibc/core/client/v1/upgraded_client_states'
    _QUERY.methods_by_name['UpgradedConsensusState']._options = None
    _QUERY.methods_by_name['UpgradedConsensusState']._serialized_options = b'\x82\xd3\xe4\x93\x02/\x12-/ibc/core/client/v1/upgraded_consensus_states'
    _QUERYCLIENTSTATEREQUEST._serialized_start = 210
    _QUERYCLIENTSTATEREQUEST._serialized_end = 254
    _QUERYCLIENTSTATERESPONSE._serialized_start = 257
    _QUERYCLIENTSTATERESPONSE._serialized_end = 398
    _QUERYCLIENTSTATESREQUEST._serialized_start = 400
    _QUERYCLIENTSTATESREQUEST._serialized_end = 486
    _QUERYCLIENTSTATESRESPONSE._serialized_start = 489
    _QUERYCLIENTSTATESRESPONSE._serialized_end = 675
    _QUERYCONSENSUSSTATEREQUEST._serialized_start = 677
    _QUERYCONSENSUSSTATEREQUEST._serialized_end = 797
    _QUERYCONSENSUSSTATERESPONSE._serialized_start = 800
    _QUERYCONSENSUSSTATERESPONSE._serialized_end = 947
    _QUERYCONSENSUSSTATESREQUEST._serialized_start = 949
    _QUERYCONSENSUSSTATESREQUEST._serialized_end = 1057
    _QUERYCONSENSUSSTATESRESPONSE._serialized_start = 1060
    _QUERYCONSENSUSSTATESRESPONSE._serialized_end = 1229
    _QUERYCLIENTSTATUSREQUEST._serialized_start = 1231
    _QUERYCLIENTSTATUSREQUEST._serialized_end = 1276
    _QUERYCLIENTSTATUSRESPONSE._serialized_start = 1278
    _QUERYCLIENTSTATUSRESPONSE._serialized_end = 1321
    _QUERYCLIENTPARAMSREQUEST._serialized_start = 1323
    _QUERYCLIENTPARAMSREQUEST._serialized_end = 1349
    _QUERYCLIENTPARAMSRESPONSE._serialized_start = 1351
    _QUERYCLIENTPARAMSRESPONSE._serialized_end = 1422
    _QUERYUPGRADEDCLIENTSTATEREQUEST._serialized_start = 1424
    _QUERYUPGRADEDCLIENTSTATEREQUEST._serialized_end = 1457
    _QUERYUPGRADEDCLIENTSTATERESPONSE._serialized_start = 1459
    _QUERYUPGRADEDCLIENTSTATERESPONSE._serialized_end = 1546
    _QUERYUPGRADEDCONSENSUSSTATEREQUEST._serialized_start = 1548
    _QUERYUPGRADEDCONSENSUSSTATEREQUEST._serialized_end = 1584
    _QUERYUPGRADEDCONSENSUSSTATERESPONSE._serialized_start = 1586
    _QUERYUPGRADEDCONSENSUSSTATERESPONSE._serialized_end = 1679
    _QUERY._serialized_start = 1682
    _QUERY._serialized_end = 3091




from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from sentinel.types.v1 import status_pb2 as _status_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class MsgRegisterRequest(_message.Message):
    __slots__ = ['frm', 'gigabyte_prices', 'hourly_prices', 'remote_url']
    FRM_FIELD_NUMBER: _ClassVar[int]
    GIGABYTE_PRICES_FIELD_NUMBER: _ClassVar[int]
    HOURLY_PRICES_FIELD_NUMBER: _ClassVar[int]
    REMOTE_URL_FIELD_NUMBER: _ClassVar[int]
    frm: str
    gigabyte_prices: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    hourly_prices: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    remote_url: str

    def __init__(self, frm: _Optional[str]=..., gigabyte_prices: _Optional[_Iterable[_Union[(_coin_pb2.Coin, _Mapping)]]]=..., hourly_prices: _Optional[_Iterable[_Union[(_coin_pb2.Coin, _Mapping)]]]=..., remote_url: _Optional[str]=...) -> None:
        ...

class MsgRegisterResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class MsgSubscribeRequest(_message.Message):
    __slots__ = ['denom', 'frm', 'gigabytes', 'hours', 'node_address']
    DENOM_FIELD_NUMBER: _ClassVar[int]
    FRM_FIELD_NUMBER: _ClassVar[int]
    GIGABYTES_FIELD_NUMBER: _ClassVar[int]
    HOURS_FIELD_NUMBER: _ClassVar[int]
    NODE_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    denom: str
    frm: str
    gigabytes: int
    hours: int
    node_address: str

    def __init__(self, frm: _Optional[str]=..., node_address: _Optional[str]=..., gigabytes: _Optional[int]=..., hours: _Optional[int]=..., denom: _Optional[str]=...) -> None:
        ...

class MsgSubscribeResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class MsgUpdateDetailsRequest(_message.Message):
    __slots__ = ['frm', 'gigabyte_prices', 'hourly_prices', 'remote_url']
    FRM_FIELD_NUMBER: _ClassVar[int]
    GIGABYTE_PRICES_FIELD_NUMBER: _ClassVar[int]
    HOURLY_PRICES_FIELD_NUMBER: _ClassVar[int]
    REMOTE_URL_FIELD_NUMBER: _ClassVar[int]
    frm: str
    gigabyte_prices: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    hourly_prices: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    remote_url: str

    def __init__(self, frm: _Optional[str]=..., gigabyte_prices: _Optional[_Iterable[_Union[(_coin_pb2.Coin, _Mapping)]]]=..., hourly_prices: _Optional[_Iterable[_Union[(_coin_pb2.Coin, _Mapping)]]]=..., remote_url: _Optional[str]=...) -> None:
        ...

class MsgUpdateDetailsResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class MsgUpdateStatusRequest(_message.Message):
    __slots__ = ['frm', 'status']
    FRM_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    frm: str
    status: _status_pb2.Status

    def __init__(self, frm: _Optional[str]=..., status: _Optional[_Union[(_status_pb2.Status, str)]]=...) -> None:
        ...

class MsgUpdateStatusResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from .....ibc.applications.interchain_accounts.controller.v1 import controller_pb2 as ibc_dot_applications_dot_interchain__accounts_dot_controller_dot_v1_dot_controller__pb2
from .....ibc.applications.interchain_accounts.host.v1 import host_pb2 as ibc_dot_applications_dot_interchain__accounts_dot_host_dot_v1_dot_host__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5ibc/applications/interchain_accounts/v1/genesis.proto\x12\'ibc.applications.interchain_accounts.v1\x1a\x14gogoproto/gogo.proto\x1aCibc/applications/interchain_accounts/controller/v1/controller.proto\x1a7ibc/applications/interchain_accounts/host/v1/host.proto"\x95\x02\n\x0cGenesisState\x12\x8a\x01\n\x18controller_genesis_state\x18\x01 \x01(\x0b2?.ibc.applications.interchain_accounts.v1.ControllerGenesisStateB\'\xc8\xde\x1f\x00\xf2\xde\x1f\x1fyaml:"controller_genesis_state"\x12x\n\x12host_genesis_state\x18\x02 \x01(\x0b29.ibc.applications.interchain_accounts.v1.HostGenesisStateB!\xc8\xde\x1f\x00\xf2\xde\x1f\x19yaml:"host_genesis_state""\xf2\x02\n\x16ControllerGenesisState\x12o\n\x0factive_channels\x18\x01 \x03(\x0b26.ibc.applications.interchain_accounts.v1.ActiveChannelB\x1e\xc8\xde\x1f\x00\xf2\xde\x1f\x16yaml:"active_channels"\x12\x85\x01\n\x13interchain_accounts\x18\x02 \x03(\x0b2D.ibc.applications.interchain_accounts.v1.RegisteredInterchainAccountB"\xc8\xde\x1f\x00\xf2\xde\x1f\x1ayaml:"interchain_accounts"\x12\r\n\x05ports\x18\x03 \x03(\t\x12P\n\x06params\x18\x04 \x01(\x0b2:.ibc.applications.interchain_accounts.controller.v1.ParamsB\x04\xc8\xde\x1f\x00"\xe5\x02\n\x10HostGenesisState\x12o\n\x0factive_channels\x18\x01 \x03(\x0b26.ibc.applications.interchain_accounts.v1.ActiveChannelB\x1e\xc8\xde\x1f\x00\xf2\xde\x1f\x16yaml:"active_channels"\x12\x85\x01\n\x13interchain_accounts\x18\x02 \x03(\x0b2D.ibc.applications.interchain_accounts.v1.RegisteredInterchainAccountB"\xc8\xde\x1f\x00\xf2\xde\x1f\x1ayaml:"interchain_accounts"\x12\x0c\n\x04port\x18\x03 \x01(\t\x12J\n\x06params\x18\x04 \x01(\x0b24.ibc.applications.interchain_accounts.host.v1.ParamsB\x04\xc8\xde\x1f\x00"\x90\x01\n\rActiveChannel\x12/\n\rconnection_id\x18\x01 \x01(\tB\x18\xf2\xde\x1f\x14yaml:"connection_id"\x12#\n\x07port_id\x18\x02 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"port_id"\x12)\n\nchannel_id\x18\x03 \x01(\tB\x15\xf2\xde\x1f\x11yaml:"channel_id""\xa8\x01\n\x1bRegisteredInterchainAccount\x12/\n\rconnection_id\x18\x01 \x01(\tB\x18\xf2\xde\x1f\x14yaml:"connection_id"\x12#\n\x07port_id\x18\x02 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"port_id"\x123\n\x0faccount_address\x18\x03 \x01(\tB\x1a\xf2\xde\x1f\x16yaml:"account_address"BGZEgithub.com/cosmos/ibc-go/v3/modules/apps/27-interchain-accounts/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.interchain_accounts.v1.genesis_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'ZEgithub.com/cosmos/ibc-go/v3/modules/apps/27-interchain-accounts/types'
    _GENESISSTATE.fields_by_name['controller_genesis_state']._options = None
    _GENESISSTATE.fields_by_name['controller_genesis_state']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f\x1fyaml:"controller_genesis_state"'
    _GENESISSTATE.fields_by_name['host_genesis_state']._options = None
    _GENESISSTATE.fields_by_name['host_genesis_state']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f\x19yaml:"host_genesis_state"'
    _CONTROLLERGENESISSTATE.fields_by_name['active_channels']._options = None
    _CONTROLLERGENESISSTATE.fields_by_name['active_channels']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f\x16yaml:"active_channels"'
    _CONTROLLERGENESISSTATE.fields_by_name['interchain_accounts']._options = None
    _CONTROLLERGENESISSTATE.fields_by_name['interchain_accounts']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f\x1ayaml:"interchain_accounts"'
    _CONTROLLERGENESISSTATE.fields_by_name['params']._options = None
    _CONTROLLERGENESISSTATE.fields_by_name['params']._serialized_options = b'\xc8\xde\x1f\x00'
    _HOSTGENESISSTATE.fields_by_name['active_channels']._options = None
    _HOSTGENESISSTATE.fields_by_name['active_channels']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f\x16yaml:"active_channels"'
    _HOSTGENESISSTATE.fields_by_name['interchain_accounts']._options = None
    _HOSTGENESISSTATE.fields_by_name['interchain_accounts']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f\x1ayaml:"interchain_accounts"'
    _HOSTGENESISSTATE.fields_by_name['params']._options = None
    _HOSTGENESISSTATE.fields_by_name['params']._serialized_options = b'\xc8\xde\x1f\x00'
    _ACTIVECHANNEL.fields_by_name['connection_id']._options = None
    _ACTIVECHANNEL.fields_by_name['connection_id']._serialized_options = b'\xf2\xde\x1f\x14yaml:"connection_id"'
    _ACTIVECHANNEL.fields_by_name['port_id']._options = None
    _ACTIVECHANNEL.fields_by_name['port_id']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"port_id"'
    _ACTIVECHANNEL.fields_by_name['channel_id']._options = None
    _ACTIVECHANNEL.fields_by_name['channel_id']._serialized_options = b'\xf2\xde\x1f\x11yaml:"channel_id"'
    _REGISTEREDINTERCHAINACCOUNT.fields_by_name['connection_id']._options = None
    _REGISTEREDINTERCHAINACCOUNT.fields_by_name['connection_id']._serialized_options = b'\xf2\xde\x1f\x14yaml:"connection_id"'
    _REGISTEREDINTERCHAINACCOUNT.fields_by_name['port_id']._options = None
    _REGISTEREDINTERCHAINACCOUNT.fields_by_name['port_id']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"port_id"'
    _REGISTEREDINTERCHAINACCOUNT.fields_by_name['account_address']._options = None
    _REGISTEREDINTERCHAINACCOUNT.fields_by_name['account_address']._serialized_options = b'\xf2\xde\x1f\x16yaml:"account_address"'
    _GENESISSTATE._serialized_start = 247
    _GENESISSTATE._serialized_end = 524
    _CONTROLLERGENESISSTATE._serialized_start = 527
    _CONTROLLERGENESISSTATE._serialized_end = 897
    _HOSTGENESISSTATE._serialized_start = 900
    _HOSTGENESISSTATE._serialized_end = 1257
    _ACTIVECHANNEL._serialized_start = 1260
    _ACTIVECHANNEL._serialized_end = 1404
    _REGISTEREDINTERCHAINACCOUNT._serialized_start = 1407
    _REGISTEREDINTERCHAINACCOUNT._serialized_end = 1575




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional
DESCRIPTOR: _descriptor.FileDescriptor

class Params(_message.Message):
    __slots__ = ['approve_by', 'swap_denom', 'swap_enabled']
    APPROVE_BY_FIELD_NUMBER: _ClassVar[int]
    SWAP_DENOM_FIELD_NUMBER: _ClassVar[int]
    SWAP_ENABLED_FIELD_NUMBER: _ClassVar[int]
    approve_by: str
    swap_denom: str
    swap_enabled: bool

    def __init__(self, swap_enabled: bool=..., swap_denom: _Optional[str]=..., approve_by: _Optional[str]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from ....sentinel.session.v2 import params_pb2 as sentinel_dot_session_dot_v2_dot_params__pb2
from ....sentinel.session.v2 import session_pb2 as sentinel_dot_session_dot_v2_dot_session__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!sentinel/session/v2/querier.proto\x12\x13sentinel.session.v2\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a sentinel/session/v2/params.proto\x1a!sentinel/session/v2/session.proto"R\n\x14QuerySessionsRequest\x12:\n\npagination\x18\x01 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"m\n\x1eQuerySessionsForAccountRequest\x12\x0f\n\x07address\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"j\n\x1bQuerySessionsForNodeRequest\x12\x0f\n\x07address\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"m\n#QuerySessionsForSubscriptionRequest\x12\n\n\x02id\x18\x01 \x01(\x04\x12:\n\npagination\x18\x02 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"|\n!QuerySessionsForAllocationRequest\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0f\n\x07address\x18\x02 \x01(\t\x12:\n\npagination\x18\x03 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"!\n\x13QuerySessionRequest\x12\n\n\x02id\x18\x01 \x01(\x04"\x14\n\x12QueryParamsRequest"\x8a\x01\n\x15QuerySessionsResponse\x124\n\x08sessions\x18\x01 \x03(\x0b2\x1c.sentinel.session.v2.SessionB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"\x94\x01\n\x1fQuerySessionsForAccountResponse\x124\n\x08sessions\x18\x01 \x03(\x0b2\x1c.sentinel.session.v2.SessionB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"\x91\x01\n\x1cQuerySessionsForNodeResponse\x124\n\x08sessions\x18\x01 \x03(\x0b2\x1c.sentinel.session.v2.SessionB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"\x99\x01\n$QuerySessionsForSubscriptionResponse\x124\n\x08sessions\x18\x01 \x03(\x0b2\x1c.sentinel.session.v2.SessionB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"\x97\x01\n"QuerySessionsForAllocationResponse\x124\n\x08sessions\x18\x01 \x03(\x0b2\x1c.sentinel.session.v2.SessionB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"K\n\x14QuerySessionResponse\x123\n\x07session\x18\x01 \x01(\x0b2\x1c.sentinel.session.v2.SessionB\x04\xc8\xde\x1f\x00"H\n\x13QueryParamsResponse\x121\n\x06params\x18\x01 \x01(\x0b2\x1b.sentinel.session.v2.ParamsB\x04\xc8\xde\x1f\x002\xa1\t\n\x0cQueryService\x12\x82\x01\n\rQuerySessions\x12).sentinel.session.v2.QuerySessionsRequest\x1a*.sentinel.session.v2.QuerySessionsResponse"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/sentinel/sessions\x12\xb3\x01\n\x17QuerySessionsForAccount\x123.sentinel.session.v2.QuerySessionsForAccountRequest\x1a4.sentinel.session.v2.QuerySessionsForAccountResponse"-\x82\xd3\xe4\x93\x02\'\x12%/sentinel/accounts/{address}/sessions\x12\xa7\x01\n\x14QuerySessionsForNode\x120.sentinel.session.v2.QuerySessionsForNodeRequest\x1a1.sentinel.session.v2.QuerySessionsForNodeResponse"*\x82\xd3\xe4\x93\x02$\x12"/sentinel/nodes/{address}/sessions\x12\xc2\x01\n\x1cQuerySessionsForSubscription\x128.sentinel.session.v2.QuerySessionsForSubscriptionRequest\x1a9.sentinel.session.v2.QuerySessionsForSubscriptionResponse"-\x82\xd3\xe4\x93\x02\'\x12%/sentinel/subscriptions/{id}/sessions\x12\xd2\x01\n\x1aQuerySessionsForAllocation\x126.sentinel.session.v2.QuerySessionsForAllocationRequest\x1a7.sentinel.session.v2.QuerySessionsForAllocationResponse"C\x82\xd3\xe4\x93\x02=\x12;/sentinel/subscriptions/{id}/allocations/{address}/sessions\x12\x84\x01\n\x0cQuerySession\x12(.sentinel.session.v2.QuerySessionRequest\x1a).sentinel.session.v2.QuerySessionResponse"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/sentinel/sessions/{id}\x12\x8a\x01\n\x0bQueryParams\x12\'.sentinel.session.v2.QueryParamsRequest\x1a(.sentinel.session.v2.QueryParamsResponse"(\x82\xd3\xe4\x93\x02"\x12 /sentinel/modules/session/paramsB:Z0github.com/sentinel-official/hub/x/session/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.session.v2.querier_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z0github.com/sentinel-official/hub/x/session/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _QUERYSESSIONSRESPONSE.fields_by_name['sessions']._options = None
    _QUERYSESSIONSRESPONSE.fields_by_name['sessions']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYSESSIONSFORACCOUNTRESPONSE.fields_by_name['sessions']._options = None
    _QUERYSESSIONSFORACCOUNTRESPONSE.fields_by_name['sessions']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYSESSIONSFORNODERESPONSE.fields_by_name['sessions']._options = None
    _QUERYSESSIONSFORNODERESPONSE.fields_by_name['sessions']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYSESSIONSFORSUBSCRIPTIONRESPONSE.fields_by_name['sessions']._options = None
    _QUERYSESSIONSFORSUBSCRIPTIONRESPONSE.fields_by_name['sessions']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYSESSIONSFORALLOCATIONRESPONSE.fields_by_name['sessions']._options = None
    _QUERYSESSIONSFORALLOCATIONRESPONSE.fields_by_name['sessions']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYSESSIONRESPONSE.fields_by_name['session']._options = None
    _QUERYSESSIONRESPONSE.fields_by_name['session']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
    _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYSERVICE.methods_by_name['QuerySessions']._options = None
    _QUERYSERVICE.methods_by_name['QuerySessions']._serialized_options = b'\x82\xd3\xe4\x93\x02\x14\x12\x12/sentinel/sessions'
    _QUERYSERVICE.methods_by_name['QuerySessionsForAccount']._options = None
    _QUERYSERVICE.methods_by_name['QuerySessionsForAccount']._serialized_options = b"\x82\xd3\xe4\x93\x02'\x12%/sentinel/accounts/{address}/sessions"
    _QUERYSERVICE.methods_by_name['QuerySessionsForNode']._options = None
    _QUERYSERVICE.methods_by_name['QuerySessionsForNode']._serialized_options = b'\x82\xd3\xe4\x93\x02$\x12"/sentinel/nodes/{address}/sessions'
    _QUERYSERVICE.methods_by_name['QuerySessionsForSubscription']._options = None
    _QUERYSERVICE.methods_by_name['QuerySessionsForSubscription']._serialized_options = b"\x82\xd3\xe4\x93\x02'\x12%/sentinel/subscriptions/{id}/sessions"
    _QUERYSERVICE.methods_by_name['QuerySessionsForAllocation']._options = None
    _QUERYSERVICE.methods_by_name['QuerySessionsForAllocation']._serialized_options = b'\x82\xd3\xe4\x93\x02=\x12;/sentinel/subscriptions/{id}/allocations/{address}/sessions'
    _QUERYSERVICE.methods_by_name['QuerySession']._options = None
    _QUERYSERVICE.methods_by_name['QuerySession']._serialized_options = b'\x82\xd3\xe4\x93\x02\x19\x12\x17/sentinel/sessions/{id}'
    _QUERYSERVICE.methods_by_name['QueryParams']._options = None
    _QUERYSERVICE.methods_by_name['QueryParams']._serialized_options = b'\x82\xd3\xe4\x93\x02"\x12 /sentinel/modules/session/params'
    _QUERYSESSIONSREQUEST._serialized_start = 223
    _QUERYSESSIONSREQUEST._serialized_end = 305
    _QUERYSESSIONSFORACCOUNTREQUEST._serialized_start = 307
    _QUERYSESSIONSFORACCOUNTREQUEST._serialized_end = 416
    _QUERYSESSIONSFORNODEREQUEST._serialized_start = 418
    _QUERYSESSIONSFORNODEREQUEST._serialized_end = 524
    _QUERYSESSIONSFORSUBSCRIPTIONREQUEST._serialized_start = 526
    _QUERYSESSIONSFORSUBSCRIPTIONREQUEST._serialized_end = 635
    _QUERYSESSIONSFORALLOCATIONREQUEST._serialized_start = 637
    _QUERYSESSIONSFORALLOCATIONREQUEST._serialized_end = 761
    _QUERYSESSIONREQUEST._serialized_start = 763
    _QUERYSESSIONREQUEST._serialized_end = 796
    _QUERYPARAMSREQUEST._serialized_start = 798
    _QUERYPARAMSREQUEST._serialized_end = 818
    _QUERYSESSIONSRESPONSE._serialized_start = 821
    _QUERYSESSIONSRESPONSE._serialized_end = 959
    _QUERYSESSIONSFORACCOUNTRESPONSE._serialized_start = 962
    _QUERYSESSIONSFORACCOUNTRESPONSE._serialized_end = 1110
    _QUERYSESSIONSFORNODERESPONSE._serialized_start = 1113
    _QUERYSESSIONSFORNODERESPONSE._serialized_end = 1258
    _QUERYSESSIONSFORSUBSCRIPTIONRESPONSE._serialized_start = 1261
    _QUERYSESSIONSFORSUBSCRIPTIONRESPONSE._serialized_end = 1414
    _QUERYSESSIONSFORALLOCATIONRESPONSE._serialized_start = 1417
    _QUERYSESSIONSFORALLOCATIONRESPONSE._serialized_end = 1568
    _QUERYSESSIONRESPONSE._serialized_start = 1570
    _QUERYSESSIONRESPONSE._serialized_end = 1645
    _QUERYPARAMSRESPONSE._serialized_start = 1647
    _QUERYPARAMSRESPONSE._serialized_end = 1719
    _QUERYSERVICE._serialized_start = 1722
    _QUERYSERVICE._serialized_end = 2907




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional
DESCRIPTOR: _descriptor.FileDescriptor

class EventAdd(_message.Message):
    __slots__ = ['address', 'coins']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    COINS_FIELD_NUMBER: _ClassVar[int]
    address: str
    coins: str

    def __init__(self, address: _Optional[str]=..., coins: _Optional[str]=...) -> None:
        ...

class EventSubtract(_message.Message):
    __slots__ = ['address', 'coins']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    COINS_FIELD_NUMBER: _ClassVar[int]
    address: str
    coins: str

    def __init__(self, address: _Optional[str]=..., coins: _Optional[str]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from ....sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2
from ....sentinel.node.v2 import node_pb2 as sentinel_dot_node_dot_v2_dot_node__pb2
from ....sentinel.node.v2 import params_pb2 as sentinel_dot_node_dot_v2_dot_params__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1esentinel/node/v2/querier.proto\x12\x10sentinel.node.v2\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1esentinel/types/v1/status.proto\x1a\x1bsentinel/node/v2/node.proto\x1a\x1dsentinel/node/v2/params.proto"z\n\x11QueryNodesRequest\x12)\n\x06status\x18\x01 \x01(\x0e2\x19.sentinel.types.v1.Status\x12:\n\npagination\x18\x02 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"\x8d\x01\n\x18QueryNodesForPlanRequest\x12\n\n\x02id\x18\x01 \x01(\x04\x12)\n\x06status\x18\x02 \x01(\x0e2\x19.sentinel.types.v1.Status\x12:\n\npagination\x18\x03 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"#\n\x10QueryNodeRequest\x12\x0f\n\x07address\x18\x01 \x01(\t"\x14\n\x12QueryParamsRequest"~\n\x12QueryNodesResponse\x12+\n\x05nodes\x18\x01 \x03(\x0b2\x16.sentinel.node.v2.NodeB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"\x85\x01\n\x19QueryNodesForPlanResponse\x12+\n\x05nodes\x18\x01 \x03(\x0b2\x16.sentinel.node.v2.NodeB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"?\n\x11QueryNodeResponse\x12*\n\x04node\x18\x01 \x01(\x0b2\x16.sentinel.node.v2.NodeB\x04\xc8\xde\x1f\x00"E\n\x13QueryParamsResponse\x12.\n\x06params\x18\x01 \x01(\x0b2\x18.sentinel.node.v2.ParamsB\x04\xc8\xde\x1f\x002\x90\x04\n\x0cQueryService\x12p\n\nQueryNodes\x12#.sentinel.node.v2.QueryNodesRequest\x1a$.sentinel.node.v2.QueryNodesResponse"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/sentinel/nodes\x12\x90\x01\n\x11QueryNodesForPlan\x12*.sentinel.node.v2.QueryNodesForPlanRequest\x1a+.sentinel.node.v2.QueryNodesForPlanResponse""\x82\xd3\xe4\x93\x02\x1c\x12\x1a/sentinel/plans/{id}/nodes\x12w\n\tQueryNode\x12".sentinel.node.v2.QueryNodeRequest\x1a#.sentinel.node.v2.QueryNodeResponse"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/sentinel/nodes/{address}\x12\x81\x01\n\x0bQueryParams\x12$.sentinel.node.v2.QueryParamsRequest\x1a%.sentinel.node.v2.QueryParamsResponse"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/sentinel/modules/node/paramsB7Z-github.com/sentinel-official/hub/x/node/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.node.v2.querier_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/node/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _QUERYNODESRESPONSE.fields_by_name['nodes']._options = None
    _QUERYNODESRESPONSE.fields_by_name['nodes']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYNODESFORPLANRESPONSE.fields_by_name['nodes']._options = None
    _QUERYNODESFORPLANRESPONSE.fields_by_name['nodes']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYNODERESPONSE.fields_by_name['node']._options = None
    _QUERYNODERESPONSE.fields_by_name['node']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
    _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYSERVICE.methods_by_name['QueryNodes']._options = None
    _QUERYSERVICE.methods_by_name['QueryNodes']._serialized_options = b'\x82\xd3\xe4\x93\x02\x11\x12\x0f/sentinel/nodes'
    _QUERYSERVICE.methods_by_name['QueryNodesForPlan']._options = None
    _QUERYSERVICE.methods_by_name['QueryNodesForPlan']._serialized_options = b'\x82\xd3\xe4\x93\x02\x1c\x12\x1a/sentinel/plans/{id}/nodes'
    _QUERYSERVICE.methods_by_name['QueryNode']._options = None
    _QUERYSERVICE.methods_by_name['QueryNode']._serialized_options = b'\x82\xd3\xe4\x93\x02\x1b\x12\x19/sentinel/nodes/{address}'
    _QUERYSERVICE.methods_by_name['QueryParams']._options = None
    _QUERYSERVICE.methods_by_name['QueryParams']._serialized_options = b'\x82\xd3\xe4\x93\x02\x1f\x12\x1d/sentinel/modules/node/params'
    _QUERYNODESREQUEST._serialized_start = 240
    _QUERYNODESREQUEST._serialized_end = 362
    _QUERYNODESFORPLANREQUEST._serialized_start = 365
    _QUERYNODESFORPLANREQUEST._serialized_end = 506
    _QUERYNODEREQUEST._serialized_start = 508
    _QUERYNODEREQUEST._serialized_end = 543
    _QUERYPARAMSREQUEST._serialized_start = 545
    _QUERYPARAMSREQUEST._serialized_end = 565
    _QUERYNODESRESPONSE._serialized_start = 567
    _QUERYNODESRESPONSE._serialized_end = 693
    _QUERYNODESFORPLANRESPONSE._serialized_start = 696
    _QUERYNODESFORPLANRESPONSE._serialized_end = 829
    _QUERYNODERESPONSE._serialized_start = 831
    _QUERYNODERESPONSE._serialized_end = 894
    _QUERYPARAMSRESPONSE._serialized_start = 896
    _QUERYPARAMSRESPONSE._serialized_end = 965
    _QUERYSERVICE._serialized_start = 968
    _QUERYSERVICE._serialized_end = 1496




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bibc/core/client/v1/tx.proto\x12\x12ibc.core.client.v1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto"\xbb\x01\n\x0fMsgCreateClient\x12C\n\x0cclient_state\x18\x01 \x01(\x0b2\x14.google.protobuf.AnyB\x17\xf2\xde\x1f\x13yaml:"client_state"\x12I\n\x0fconsensus_state\x18\x02 \x01(\x0b2\x14.google.protobuf.AnyB\x1a\xf2\xde\x1f\x16yaml:"consensus_state"\x12\x0e\n\x06signer\x18\x03 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\x19\n\x17MsgCreateClientResponse"z\n\x0fMsgUpdateClient\x12\'\n\tclient_id\x18\x01 \x01(\tB\x14\xf2\xde\x1f\x10yaml:"client_id"\x12$\n\x06header\x18\x02 \x01(\x0b2\x14.google.protobuf.Any\x12\x0e\n\x06signer\x18\x03 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\x19\n\x17MsgUpdateClientResponse"\xf5\x02\n\x10MsgUpgradeClient\x12\'\n\tclient_id\x18\x01 \x01(\tB\x14\xf2\xde\x1f\x10yaml:"client_id"\x12C\n\x0cclient_state\x18\x02 \x01(\x0b2\x14.google.protobuf.AnyB\x17\xf2\xde\x1f\x13yaml:"client_state"\x12I\n\x0fconsensus_state\x18\x03 \x01(\x0b2\x14.google.protobuf.AnyB\x1a\xf2\xde\x1f\x16yaml:"consensus_state"\x12=\n\x14proof_upgrade_client\x18\x04 \x01(\x0cB\x1f\xf2\xde\x1f\x1byaml:"proof_upgrade_client"\x12O\n\x1dproof_upgrade_consensus_state\x18\x05 \x01(\x0cB(\xf2\xde\x1f$yaml:"proof_upgrade_consensus_state"\x12\x0e\n\x06signer\x18\x06 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\x1a\n\x18MsgUpgradeClientResponse"\x86\x01\n\x15MsgSubmitMisbehaviour\x12\'\n\tclient_id\x18\x01 \x01(\tB\x14\xf2\xde\x1f\x10yaml:"client_id"\x12*\n\x0cmisbehaviour\x18\x02 \x01(\x0b2\x14.google.protobuf.Any\x12\x0e\n\x06signer\x18\x03 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\x1f\n\x1dMsgSubmitMisbehaviourResponse2\xa2\x03\n\x03Msg\x12`\n\x0cCreateClient\x12#.ibc.core.client.v1.MsgCreateClient\x1a+.ibc.core.client.v1.MsgCreateClientResponse\x12`\n\x0cUpdateClient\x12#.ibc.core.client.v1.MsgUpdateClient\x1a+.ibc.core.client.v1.MsgUpdateClientResponse\x12c\n\rUpgradeClient\x12$.ibc.core.client.v1.MsgUpgradeClient\x1a,.ibc.core.client.v1.MsgUpgradeClientResponse\x12r\n\x12SubmitMisbehaviour\x12).ibc.core.client.v1.MsgSubmitMisbehaviour\x1a1.ibc.core.client.v1.MsgSubmitMisbehaviourResponseB:Z8github.com/cosmos/ibc-go/v3/modules/core/02-client/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.client.v1.tx_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z8github.com/cosmos/ibc-go/v3/modules/core/02-client/types'
    _MSGCREATECLIENT.fields_by_name['client_state']._options = None
    _MSGCREATECLIENT.fields_by_name['client_state']._serialized_options = b'\xf2\xde\x1f\x13yaml:"client_state"'
    _MSGCREATECLIENT.fields_by_name['consensus_state']._options = None
    _MSGCREATECLIENT.fields_by_name['consensus_state']._serialized_options = b'\xf2\xde\x1f\x16yaml:"consensus_state"'
    _MSGCREATECLIENT._options = None
    _MSGCREATECLIENT._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _MSGUPDATECLIENT.fields_by_name['client_id']._options = None
    _MSGUPDATECLIENT.fields_by_name['client_id']._serialized_options = b'\xf2\xde\x1f\x10yaml:"client_id"'
    _MSGUPDATECLIENT._options = None
    _MSGUPDATECLIENT._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _MSGUPGRADECLIENT.fields_by_name['client_id']._options = None
    _MSGUPGRADECLIENT.fields_by_name['client_id']._serialized_options = b'\xf2\xde\x1f\x10yaml:"client_id"'
    _MSGUPGRADECLIENT.fields_by_name['client_state']._options = None
    _MSGUPGRADECLIENT.fields_by_name['client_state']._serialized_options = b'\xf2\xde\x1f\x13yaml:"client_state"'
    _MSGUPGRADECLIENT.fields_by_name['consensus_state']._options = None
    _MSGUPGRADECLIENT.fields_by_name['consensus_state']._serialized_options = b'\xf2\xde\x1f\x16yaml:"consensus_state"'
    _MSGUPGRADECLIENT.fields_by_name['proof_upgrade_client']._options = None
    _MSGUPGRADECLIENT.fields_by_name['proof_upgrade_client']._serialized_options = b'\xf2\xde\x1f\x1byaml:"proof_upgrade_client"'
    _MSGUPGRADECLIENT.fields_by_name['proof_upgrade_consensus_state']._options = None
    _MSGUPGRADECLIENT.fields_by_name['proof_upgrade_consensus_state']._serialized_options = b'\xf2\xde\x1f$yaml:"proof_upgrade_consensus_state"'
    _MSGUPGRADECLIENT._options = None
    _MSGUPGRADECLIENT._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _MSGSUBMITMISBEHAVIOUR.fields_by_name['client_id']._options = None
    _MSGSUBMITMISBEHAVIOUR.fields_by_name['client_id']._serialized_options = b'\xf2\xde\x1f\x10yaml:"client_id"'
    _MSGSUBMITMISBEHAVIOUR._options = None
    _MSGSUBMITMISBEHAVIOUR._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _MSGCREATECLIENT._serialized_start = 101
    _MSGCREATECLIENT._serialized_end = 288
    _MSGCREATECLIENTRESPONSE._serialized_start = 290
    _MSGCREATECLIENTRESPONSE._serialized_end = 315
    _MSGUPDATECLIENT._serialized_start = 317
    _MSGUPDATECLIENT._serialized_end = 439
    _MSGUPDATECLIENTRESPONSE._serialized_start = 441
    _MSGUPDATECLIENTRESPONSE._serialized_end = 466
    _MSGUPGRADECLIENT._serialized_start = 469
    _MSGUPGRADECLIENT._serialized_end = 842
    _MSGUPGRADECLIENTRESPONSE._serialized_start = 844
    _MSGUPGRADECLIENTRESPONSE._serialized_end = 870
    _MSGSUBMITMISBEHAVIOUR._serialized_start = 873
    _MSGSUBMITMISBEHAVIOUR._serialized_end = 1007
    _MSGSUBMITMISBEHAVIOURRESPONSE._serialized_start = 1009
    _MSGSUBMITMISBEHAVIOURRESPONSE._serialized_end = 1040
    _MSG._serialized_start = 1043
    _MSG._serialized_end = 1461




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from ....google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cosmos/evidence/v1beta1/query.proto\x12\x17cosmos.evidence.v1beta1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/api/annotations.proto"g\n\x14QueryEvidenceRequest\x12O\n\revidence_hash\x18\x01 \x01(\x0cB8\xfa\xde\x1f4github.com/tendermint/tendermint/libs/bytes.HexBytes"?\n\x15QueryEvidenceResponse\x12&\n\x08evidence\x18\x01 \x01(\x0b2\x14.google.protobuf.Any"U\n\x17QueryAllEvidenceRequest\x12:\n\npagination\x18\x01 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"\x7f\n\x18QueryAllEvidenceResponse\x12&\n\x08evidence\x18\x01 \x03(\x0b2\x14.google.protobuf.Any\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse2\xce\x02\n\x05Query\x12\xa4\x01\n\x08Evidence\x12-.cosmos.evidence.v1beta1.QueryEvidenceRequest\x1a..cosmos.evidence.v1beta1.QueryEvidenceResponse"9\x82\xd3\xe4\x93\x023\x121/cosmos/evidence/v1beta1/evidence/{evidence_hash}\x12\x9d\x01\n\x0bAllEvidence\x120.cosmos.evidence.v1beta1.QueryAllEvidenceRequest\x1a1.cosmos.evidence.v1beta1.QueryAllEvidenceResponse")\x82\xd3\xe4\x93\x02#\x12!/cosmos/evidence/v1beta1/evidenceB/Z-github.com/cosmos/cosmos-sdk/x/evidence/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.evidence.v1beta1.query_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z-github.com/cosmos/cosmos-sdk/x/evidence/types'
    _QUERYEVIDENCEREQUEST.fields_by_name['evidence_hash']._options = None
    _QUERYEVIDENCEREQUEST.fields_by_name['evidence_hash']._serialized_options = b'\xfa\xde\x1f4github.com/tendermint/tendermint/libs/bytes.HexBytes'
    _QUERY.methods_by_name['Evidence']._options = None
    _QUERY.methods_by_name['Evidence']._serialized_options = b'\x82\xd3\xe4\x93\x023\x121/cosmos/evidence/v1beta1/evidence/{evidence_hash}'
    _QUERY.methods_by_name['AllEvidence']._options = None
    _QUERY.methods_by_name['AllEvidence']._serialized_options = b'\x82\xd3\xe4\x93\x02#\x12!/cosmos/evidence/v1beta1/evidence'
    _QUERYEVIDENCEREQUEST._serialized_start = 187
    _QUERYEVIDENCEREQUEST._serialized_end = 290
    _QUERYEVIDENCERESPONSE._serialized_start = 292
    _QUERYEVIDENCERESPONSE._serialized_end = 355
    _QUERYALLEVIDENCEREQUEST._serialized_start = 357
    _QUERYALLEVIDENCEREQUEST._serialized_end = 442
    _QUERYALLEVIDENCERESPONSE._serialized_start = 444
    _QUERYALLEVIDENCERESPONSE._serialized_end = 571
    _QUERY._serialized_start = 574
    _QUERY._serialized_end = 908




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19cosmos_proto/cosmos.proto\x12\x0ccosmos_proto\x1a google/protobuf/descriptor.proto"8\n\x13InterfaceDescriptor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0bdescription\x18\x02 \x01(\t"c\n\x10ScalarDescriptor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0bdescription\x18\x02 \x01(\t\x12,\n\nfield_type\x18\x03 \x03(\x0e2\x18.cosmos_proto.ScalarType*X\n\nScalarType\x12\x1b\n\x17SCALAR_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12SCALAR_TYPE_STRING\x10\x01\x12\x15\n\x11SCALAR_TYPE_BYTES\x10\x02:?\n\x14implements_interface\x12\x1f.google.protobuf.MessageOptions\x18\xc9\xd6\x05 \x03(\t::\n\x11accepts_interface\x12\x1d.google.protobuf.FieldOptions\x18\xc9\xd6\x05 \x01(\t:/\n\x06scalar\x12\x1d.google.protobuf.FieldOptions\x18\xca\xd6\x05 \x01(\t:\\\n\x11declare_interface\x12\x1c.google.protobuf.FileOptions\x18\xbd\xb30 \x03(\x0b2!.cosmos_proto.InterfaceDescriptor:V\n\x0edeclare_scalar\x12\x1c.google.protobuf.FileOptions\x18\xbe\xb30 \x03(\x0b2\x1e.cosmos_proto.ScalarDescriptorB-Z+github.com/cosmos/cosmos-proto;cosmos_protob\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos_proto.cosmos_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(implements_interface)
    google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(accepts_interface)
    google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(scalar)
    google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(declare_interface)
    google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(declare_scalar)
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z+github.com/cosmos/cosmos-proto;cosmos_proto'
    _SCALARTYPE._serialized_start = 236
    _SCALARTYPE._serialized_end = 324
    _INTERFACEDESCRIPTOR._serialized_start = 77
    _INTERFACEDESCRIPTOR._serialized_end = 133
    _SCALARDESCRIPTOR._serialized_start = 135
    _SCALARDESCRIPTOR._serialized_end = 234




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,cosmos/base/snapshots/v1beta1/snapshot.proto\x12\x1dcosmos.base.snapshots.v1beta1\x1a\x14gogoproto/gogo.proto"\x89\x01\n\x08Snapshot\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x0e\n\x06format\x18\x02 \x01(\r\x12\x0e\n\x06chunks\x18\x03 \x01(\r\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\x12?\n\x08metadata\x18\x05 \x01(\x0b2\'.cosmos.base.snapshots.v1beta1.MetadataB\x04\xc8\xde\x1f\x00" \n\x08Metadata\x12\x14\n\x0cchunk_hashes\x18\x01 \x03(\x0c"\xc5\x02\n\x0cSnapshotItem\x12A\n\x05store\x18\x01 \x01(\x0b20.cosmos.base.snapshots.v1beta1.SnapshotStoreItemH\x00\x12I\n\x04iavl\x18\x02 \x01(\x0b2/.cosmos.base.snapshots.v1beta1.SnapshotIAVLItemB\x08\xe2\xde\x1f\x04IAVLH\x00\x12I\n\textension\x18\x03 \x01(\x0b24.cosmos.base.snapshots.v1beta1.SnapshotExtensionMetaH\x00\x12T\n\x11extension_payload\x18\x04 \x01(\x0b27.cosmos.base.snapshots.v1beta1.SnapshotExtensionPayloadH\x00B\x06\n\x04item"!\n\x11SnapshotStoreItem\x12\x0c\n\x04name\x18\x01 \x01(\t"O\n\x10SnapshotIAVLItem\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\x0f\n\x07version\x18\x03 \x01(\x03\x12\x0e\n\x06height\x18\x04 \x01(\x05"5\n\x15SnapshotExtensionMeta\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06format\x18\x02 \x01(\r"+\n\x18SnapshotExtensionPayload\x12\x0f\n\x07payload\x18\x01 \x01(\x0cB.Z,github.com/cosmos/cosmos-sdk/snapshots/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.snapshots.v1beta1.snapshot_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z,github.com/cosmos/cosmos-sdk/snapshots/types'
    _SNAPSHOT.fields_by_name['metadata']._options = None
    _SNAPSHOT.fields_by_name['metadata']._serialized_options = b'\xc8\xde\x1f\x00'
    _SNAPSHOTITEM.fields_by_name['iavl']._options = None
    _SNAPSHOTITEM.fields_by_name['iavl']._serialized_options = b'\xe2\xde\x1f\x04IAVL'
    _SNAPSHOT._serialized_start = 102
    _SNAPSHOT._serialized_end = 239
    _METADATA._serialized_start = 241
    _METADATA._serialized_end = 273
    _SNAPSHOTITEM._serialized_start = 276
    _SNAPSHOTITEM._serialized_end = 601
    _SNAPSHOTSTOREITEM._serialized_start = 603
    _SNAPSHOTSTOREITEM._serialized_end = 636
    _SNAPSHOTIAVLITEM._serialized_start = 638
    _SNAPSHOTIAVLITEM._serialized_end = 717
    _SNAPSHOTEXTENSIONMETA._serialized_start = 719
    _SNAPSHOTEXTENSIONMETA._serialized_end = 772
    _SNAPSHOTEXTENSIONPAYLOAD._serialized_start = 774
    _SNAPSHOTEXTENSIONPAYLOAD._serialized_end = 817




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dsentinel/plan/v2/events.proto\x12\x10sentinel.plan.v2\x1a\x14gogoproto/gogo.proto\x1a\x1esentinel/types/v1/status.proto"S\n\x0bEventCreate\x12#\n\x07address\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"address"\x12\x1f\n\x02id\x18\x02 \x01(\x04B\x13\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:"id""\x97\x01\n\x11EventUpdateStatus\x12<\n\x06status\x18\x01 \x01(\x0e2\x19.sentinel.types.v1.StatusB\x11\xf2\xde\x1f\ryaml:"status"\x12#\n\x07address\x18\x02 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"address"\x12\x1f\n\x02id\x18\x03 \x01(\x04B\x13\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:"id""\x84\x01\n\rEventLinkNode\x12#\n\x07address\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"address"\x12-\n\x0cnode_address\x18\x02 \x01(\tB\x17\xf2\xde\x1f\x13yaml:"node_address"\x12\x1f\n\x02id\x18\x03 \x01(\x04B\x13\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:"id""\x86\x01\n\x0fEventUnlinkNode\x12#\n\x07address\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"address"\x12-\n\x0cnode_address\x18\x02 \x01(\tB\x17\xf2\xde\x1f\x13yaml:"node_address"\x12\x1f\n\x02id\x18\x03 \x01(\x04B\x13\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:"id""\xc5\x01\n\x17EventCreateSubscription\x12#\n\x07address\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"address"\x125\n\x10provider_address\x18\x02 \x01(\tB\x1b\xf2\xde\x1f\x17yaml:"provider_address"\x12\x1f\n\x02id\x18\x03 \x01(\x04B\x13\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:"id"\x12-\n\x07plan_id\x18\x04 \x01(\x04B\x1c\xe2\xde\x1f\x06PlanID\xf2\xde\x1f\x0eyaml:"plan_id"B7Z-github.com/sentinel-official/hub/x/plan/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.plan.v2.events_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/plan/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _EVENTCREATE.fields_by_name['address']._options = None
    _EVENTCREATE.fields_by_name['address']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"address"'
    _EVENTCREATE.fields_by_name['id']._options = None
    _EVENTCREATE.fields_by_name['id']._serialized_options = b'\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:"id"'
    _EVENTUPDATESTATUS.fields_by_name['status']._options = None
    _EVENTUPDATESTATUS.fields_by_name['status']._serialized_options = b'\xf2\xde\x1f\ryaml:"status"'
    _EVENTUPDATESTATUS.fields_by_name['address']._options = None
    _EVENTUPDATESTATUS.fields_by_name['address']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"address"'
    _EVENTUPDATESTATUS.fields_by_name['id']._options = None
    _EVENTUPDATESTATUS.fields_by_name['id']._serialized_options = b'\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:"id"'
    _EVENTLINKNODE.fields_by_name['address']._options = None
    _EVENTLINKNODE.fields_by_name['address']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"address"'
    _EVENTLINKNODE.fields_by_name['node_address']._options = None
    _EVENTLINKNODE.fields_by_name['node_address']._serialized_options = b'\xf2\xde\x1f\x13yaml:"node_address"'
    _EVENTLINKNODE.fields_by_name['id']._options = None
    _EVENTLINKNODE.fields_by_name['id']._serialized_options = b'\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:"id"'
    _EVENTUNLINKNODE.fields_by_name['address']._options = None
    _EVENTUNLINKNODE.fields_by_name['address']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"address"'
    _EVENTUNLINKNODE.fields_by_name['node_address']._options = None
    _EVENTUNLINKNODE.fields_by_name['node_address']._serialized_options = b'\xf2\xde\x1f\x13yaml:"node_address"'
    _EVENTUNLINKNODE.fields_by_name['id']._options = None
    _EVENTUNLINKNODE.fields_by_name['id']._serialized_options = b'\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:"id"'
    _EVENTCREATESUBSCRIPTION.fields_by_name['address']._options = None
    _EVENTCREATESUBSCRIPTION.fields_by_name['address']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"address"'
    _EVENTCREATESUBSCRIPTION.fields_by_name['provider_address']._options = None
    _EVENTCREATESUBSCRIPTION.fields_by_name['provider_address']._serialized_options = b'\xf2\xde\x1f\x17yaml:"provider_address"'
    _EVENTCREATESUBSCRIPTION.fields_by_name['id']._options = None
    _EVENTCREATESUBSCRIPTION.fields_by_name['id']._serialized_options = b'\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:"id"'
    _EVENTCREATESUBSCRIPTION.fields_by_name['plan_id']._options = None
    _EVENTCREATESUBSCRIPTION.fields_by_name['plan_id']._serialized_options = b'\xe2\xde\x1f\x06PlanID\xf2\xde\x1f\x0eyaml:"plan_id"'
    _EVENTCREATE._serialized_start = 105
    _EVENTCREATE._serialized_end = 188
    _EVENTUPDATESTATUS._serialized_start = 191
    _EVENTUPDATESTATUS._serialized_end = 342
    _EVENTLINKNODE._serialized_start = 345
    _EVENTLINKNODE._serialized_end = 477
    _EVENTUNLINKNODE._serialized_start = 480
    _EVENTUNLINKNODE._serialized_end = 614
    _EVENTCREATESUBSCRIPTION._serialized_start = 617
    _EVENTCREATESUBSCRIPTION._serialized_end = 814




from gogoproto import gogo_pb2 as _gogo_pb2
from ibc.core.channel.v1 import channel_pb2 as _channel_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ['ack_sequences', 'acknowledgements', 'channels', 'commitments', 'next_channel_sequence', 'receipts', 'recv_sequences', 'send_sequences']
    ACKNOWLEDGEMENTS_FIELD_NUMBER: _ClassVar[int]
    ACK_SEQUENCES_FIELD_NUMBER: _ClassVar[int]
    CHANNELS_FIELD_NUMBER: _ClassVar[int]
    COMMITMENTS_FIELD_NUMBER: _ClassVar[int]
    NEXT_CHANNEL_SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    RECEIPTS_FIELD_NUMBER: _ClassVar[int]
    RECV_SEQUENCES_FIELD_NUMBER: _ClassVar[int]
    SEND_SEQUENCES_FIELD_NUMBER: _ClassVar[int]
    ack_sequences: _containers.RepeatedCompositeFieldContainer[PacketSequence]
    acknowledgements: _containers.RepeatedCompositeFieldContainer[_channel_pb2.PacketState]
    channels: _containers.RepeatedCompositeFieldContainer[_channel_pb2.IdentifiedChannel]
    commitments: _containers.RepeatedCompositeFieldContainer[_channel_pb2.PacketState]
    next_channel_sequence: int
    receipts: _containers.RepeatedCompositeFieldContainer[_channel_pb2.PacketState]
    recv_sequences: _containers.RepeatedCompositeFieldContainer[PacketSequence]
    send_sequences: _containers.RepeatedCompositeFieldContainer[PacketSequence]

    def __init__(self, channels: _Optional[_Iterable[_Union[(_channel_pb2.IdentifiedChannel, _Mapping)]]]=..., acknowledgements: _Optional[_Iterable[_Union[(_channel_pb2.PacketState, _Mapping)]]]=..., commitments: _Optional[_Iterable[_Union[(_channel_pb2.PacketState, _Mapping)]]]=..., receipts: _Optional[_Iterable[_Union[(_channel_pb2.PacketState, _Mapping)]]]=..., send_sequences: _Optional[_Iterable[_Union[(PacketSequence, _Mapping)]]]=..., recv_sequences: _Optional[_Iterable[_Union[(PacketSequence, _Mapping)]]]=..., ack_sequences: _Optional[_Iterable[_Union[(PacketSequence, _Mapping)]]]=..., next_channel_sequence: _Optional[int]=...) -> None:
        ...

class PacketSequence(_message.Message):
    __slots__ = ['channel_id', 'port_id', 'sequence']
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    channel_id: str
    port_id: str
    sequence: int

    def __init__(self, port_id: _Optional[str]=..., channel_id: _Optional[str]=..., sequence: _Optional[int]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ecosmos/auth/v1beta1/auth.proto\x12\x13cosmos.auth.v1beta1\x1a\x19cosmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto"\xd3\x01\n\x0bBaseAccount\x12\x0f\n\x07address\x18\x01 \x01(\t\x12T\n\x07pub_key\x18\x02 \x01(\x0b2\x14.google.protobuf.AnyB-\xea\xde\x1f\x14public_key,omitempty\xf2\xde\x1f\x11yaml:"public_key"\x121\n\x0eaccount_number\x18\x03 \x01(\x04B\x19\xf2\xde\x1f\x15yaml:"account_number"\x12\x10\n\x08sequence\x18\x04 \x01(\x04:\x18\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x08AccountI"\xa3\x01\n\rModuleAccount\x12S\n\x0cbase_account\x18\x01 \x01(\x0b2 .cosmos.auth.v1beta1.BaseAccountB\x1b\xd0\xde\x1f\x01\xf2\xde\x1f\x13yaml:"base_account"\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0bpermissions\x18\x03 \x03(\t:\x1a\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xca\xb4-\x0eModuleAccountI"\xff\x02\n\x06Params\x12;\n\x13max_memo_characters\x18\x01 \x01(\x04B\x1e\xf2\xde\x1f\x1ayaml:"max_memo_characters"\x12-\n\x0ctx_sig_limit\x18\x02 \x01(\x04B\x17\xf2\xde\x1f\x13yaml:"tx_sig_limit"\x12?\n\x15tx_size_cost_per_byte\x18\x03 \x01(\x04B \xf2\xde\x1f\x1cyaml:"tx_size_cost_per_byte"\x12[\n\x17sig_verify_cost_ed25519\x18\x04 \x01(\x04B:\xe2\xde\x1f\x14SigVerifyCostED25519\xf2\xde\x1f\x1eyaml:"sig_verify_cost_ed25519"\x12a\n\x19sig_verify_cost_secp256k1\x18\x05 \x01(\x04B>\xe2\xde\x1f\x16SigVerifyCostSecp256k1\xf2\xde\x1f yaml:"sig_verify_cost_secp256k1":\x08\xe8\xa0\x1f\x01\x98\xa0\x1f\x00B+Z)github.com/cosmos/cosmos-sdk/x/auth/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.auth.v1beta1.auth_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/auth/types'
    _BASEACCOUNT.fields_by_name['pub_key']._options = None
    _BASEACCOUNT.fields_by_name['pub_key']._serialized_options = b'\xea\xde\x1f\x14public_key,omitempty\xf2\xde\x1f\x11yaml:"public_key"'
    _BASEACCOUNT.fields_by_name['account_number']._options = None
    _BASEACCOUNT.fields_by_name['account_number']._serialized_options = b'\xf2\xde\x1f\x15yaml:"account_number"'
    _BASEACCOUNT._options = None
    _BASEACCOUNT._serialized_options = b'\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x08AccountI'
    _MODULEACCOUNT.fields_by_name['base_account']._options = None
    _MODULEACCOUNT.fields_by_name['base_account']._serialized_options = b'\xd0\xde\x1f\x01\xf2\xde\x1f\x13yaml:"base_account"'
    _MODULEACCOUNT._options = None
    _MODULEACCOUNT._serialized_options = b'\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xca\xb4-\x0eModuleAccountI'
    _PARAMS.fields_by_name['max_memo_characters']._options = None
    _PARAMS.fields_by_name['max_memo_characters']._serialized_options = b'\xf2\xde\x1f\x1ayaml:"max_memo_characters"'
    _PARAMS.fields_by_name['tx_sig_limit']._options = None
    _PARAMS.fields_by_name['tx_sig_limit']._serialized_options = b'\xf2\xde\x1f\x13yaml:"tx_sig_limit"'
    _PARAMS.fields_by_name['tx_size_cost_per_byte']._options = None
    _PARAMS.fields_by_name['tx_size_cost_per_byte']._serialized_options = b'\xf2\xde\x1f\x1cyaml:"tx_size_cost_per_byte"'
    _PARAMS.fields_by_name['sig_verify_cost_ed25519']._options = None
    _PARAMS.fields_by_name['sig_verify_cost_ed25519']._serialized_options = b'\xe2\xde\x1f\x14SigVerifyCostED25519\xf2\xde\x1f\x1eyaml:"sig_verify_cost_ed25519"'
    _PARAMS.fields_by_name['sig_verify_cost_secp256k1']._options = None
    _PARAMS.fields_by_name['sig_verify_cost_secp256k1']._serialized_options = b'\xe2\xde\x1f\x16SigVerifyCostSecp256k1\xf2\xde\x1f yaml:"sig_verify_cost_secp256k1"'
    _PARAMS._options = None
    _PARAMS._serialized_options = b'\xe8\xa0\x1f\x01\x98\xa0\x1f\x00'
    _BASEACCOUNT._serialized_start = 132
    _BASEACCOUNT._serialized_end = 343
    _MODULEACCOUNT._serialized_start = 346
    _MODULEACCOUNT._serialized_end = 509
    _PARAMS._serialized_start = 512
    _PARAMS._serialized_end = 895




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/cosmos/base/reflection/v1beta1/reflection.proto\x12\x1ecosmos.base.reflection.v1beta1\x1a\x1cgoogle/api/annotations.proto"\x1a\n\x18ListAllInterfacesRequest"4\n\x19ListAllInterfacesResponse\x12\x17\n\x0finterface_names\x18\x01 \x03(\t"4\n\x1aListImplementationsRequest\x12\x16\n\x0einterface_name\x18\x01 \x01(\t"C\n\x1bListImplementationsResponse\x12$\n\x1cimplementation_message_names\x18\x01 \x03(\t2\xb8\x03\n\x11ReflectionService\x12\xbc\x01\n\x11ListAllInterfaces\x128.cosmos.base.reflection.v1beta1.ListAllInterfacesRequest\x1a9.cosmos.base.reflection.v1beta1.ListAllInterfacesResponse"2\x82\xd3\xe4\x93\x02,\x12*/cosmos/base/reflection/v1beta1/interfaces\x12\xe3\x01\n\x13ListImplementations\x12:.cosmos.base.reflection.v1beta1.ListImplementationsRequest\x1a;.cosmos.base.reflection.v1beta1.ListImplementationsResponse"S\x82\xd3\xe4\x93\x02M\x12K/cosmos/base/reflection/v1beta1/interfaces/{interface_name}/implementationsB5Z3github.com/cosmos/cosmos-sdk/client/grpc/reflectionb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.reflection.v1beta1.reflection_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z3github.com/cosmos/cosmos-sdk/client/grpc/reflection'
    _REFLECTIONSERVICE.methods_by_name['ListAllInterfaces']._options = None
    _REFLECTIONSERVICE.methods_by_name['ListAllInterfaces']._serialized_options = b'\x82\xd3\xe4\x93\x02,\x12*/cosmos/base/reflection/v1beta1/interfaces'
    _REFLECTIONSERVICE.methods_by_name['ListImplementations']._options = None
    _REFLECTIONSERVICE.methods_by_name['ListImplementations']._serialized_options = b'\x82\xd3\xe4\x93\x02M\x12K/cosmos/base/reflection/v1beta1/interfaces/{interface_name}/implementations'
    _LISTALLINTERFACESREQUEST._serialized_start = 113
    _LISTALLINTERFACESREQUEST._serialized_end = 139
    _LISTALLINTERFACESRESPONSE._serialized_start = 141
    _LISTALLINTERFACESRESPONSE._serialized_end = 193
    _LISTIMPLEMENTATIONSREQUEST._serialized_start = 195
    _LISTIMPLEMENTATIONSREQUEST._serialized_end = 247
    _LISTIMPLEMENTATIONSRESPONSE._serialized_start = 249
    _LISTIMPLEMENTATIONSRESPONSE._serialized_end = 316
    _REFLECTIONSERVICE._serialized_start = 319
    _REFLECTIONSERVICE._serialized_end = 759




from tendermint.p2p import types_pb2 as _types_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class Message(_message.Message):
    __slots__ = ['pex_addrs', 'pex_request']
    PEX_ADDRS_FIELD_NUMBER: _ClassVar[int]
    PEX_REQUEST_FIELD_NUMBER: _ClassVar[int]
    pex_addrs: PexAddrs
    pex_request: PexRequest

    def __init__(self, pex_request: _Optional[_Union[(PexRequest, _Mapping)]]=..., pex_addrs: _Optional[_Union[(PexAddrs, _Mapping)]]=...) -> None:
        ...

class PexAddrs(_message.Message):
    __slots__ = ['addrs']
    ADDRS_FIELD_NUMBER: _ClassVar[int]
    addrs: _containers.RepeatedCompositeFieldContainer[_types_pb2.NetAddress]

    def __init__(self, addrs: _Optional[_Iterable[_Union[(_types_pb2.NetAddress, _Mapping)]]]=...) -> None:
        ...

class PexRequest(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#interchain_security/ccv/v1/tx.proto\x12\x1ainterchain_security.ccv.v12\x05\n\x03MsgB3Z1github.com/cosmos/interchain-security/x/ccv/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'interchain_security.ccv.v1.tx_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z1github.com/cosmos/interchain-security/x/ccv/types'
    _MSG._serialized_start = 67
    _MSG._serialized_end = 72




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!sentinel/provider/v2/events.proto\x12\x14sentinel.provider.v2\x1a\x14gogoproto/gogo.proto"4\n\rEventRegister\x12#\n\x07address\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"address""2\n\x0bEventUpdate\x12#\n\x07address\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"address"B;Z1github.com/sentinel-official/hub/x/provider/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.provider.v2.events_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z1github.com/sentinel-official/hub/x/provider/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _EVENTREGISTER.fields_by_name['address']._options = None
    _EVENTREGISTER.fields_by_name['address']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"address"'
    _EVENTUPDATE.fields_by_name['address']._options = None
    _EVENTUPDATE.fields_by_name['address']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"address"'
    _EVENTREGISTER._serialized_start = 81
    _EVENTREGISTER._serialized_end = 133
    _EVENTUPDATE._serialized_start = 135
    _EVENTUPDATE._serialized_end = 185




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import any_pb2 as _any_pb2
from cosmos_proto import cosmos_pb2 as _cosmos_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class MsgSubmitEvidence(_message.Message):
    __slots__ = ['evidence', 'submitter']
    EVIDENCE_FIELD_NUMBER: _ClassVar[int]
    SUBMITTER_FIELD_NUMBER: _ClassVar[int]
    evidence: _any_pb2.Any
    submitter: str

    def __init__(self, submitter: _Optional[str]=..., evidence: _Optional[_Union[(_any_pb2.Any, _Mapping)]]=...) -> None:
        ...

class MsgSubmitEvidenceResponse(_message.Message):
    __slots__ = ['hash']
    HASH_FIELD_NUMBER: _ClassVar[int]
    hash: bytes

    def __init__(self, hash: _Optional[bytes]=...) -> None:
        ...




from gogoproto import gogo_pb2 as _gogo_pb2
from sentinel.types.v1 import status_pb2 as _status_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class EventAllocate(_message.Message):
    __slots__ = ['address', 'granted_bytes', 'id', 'utilised_bytes']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    GRANTED_BYTES_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    UTILISED_BYTES_FIELD_NUMBER: _ClassVar[int]
    address: str
    granted_bytes: str
    id: int
    utilised_bytes: str

    def __init__(self, address: _Optional[str]=..., granted_bytes: _Optional[str]=..., utilised_bytes: _Optional[str]=..., id: _Optional[int]=...) -> None:
        ...

class EventCreatePayout(_message.Message):
    __slots__ = ['address', 'id', 'node_address']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NODE_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    address: str
    id: int
    node_address: str

    def __init__(self, address: _Optional[str]=..., node_address: _Optional[str]=..., id: _Optional[int]=...) -> None:
        ...

class EventPayForPayout(_message.Message):
    __slots__ = ['address', 'id', 'node_address', 'payment', 'staking_reward']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NODE_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PAYMENT_FIELD_NUMBER: _ClassVar[int]
    STAKING_REWARD_FIELD_NUMBER: _ClassVar[int]
    address: str
    id: int
    node_address: str
    payment: str
    staking_reward: str

    def __init__(self, address: _Optional[str]=..., node_address: _Optional[str]=..., payment: _Optional[str]=..., staking_reward: _Optional[str]=..., id: _Optional[int]=...) -> None:
        ...

class EventPayForPlan(_message.Message):
    __slots__ = ['address', 'id', 'payment', 'provider_address', 'staking_reward']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    PAYMENT_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    STAKING_REWARD_FIELD_NUMBER: _ClassVar[int]
    address: str
    id: int
    payment: str
    provider_address: str
    staking_reward: str

    def __init__(self, address: _Optional[str]=..., payment: _Optional[str]=..., provider_address: _Optional[str]=..., staking_reward: _Optional[str]=..., id: _Optional[int]=...) -> None:
        ...

class EventPayForSession(_message.Message):
    __slots__ = ['address', 'node_address', 'payment', 'session_id', 'staking_reward', 'subscription_id']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    NODE_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PAYMENT_FIELD_NUMBER: _ClassVar[int]
    SESSION_ID_FIELD_NUMBER: _ClassVar[int]
    STAKING_REWARD_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIPTION_ID_FIELD_NUMBER: _ClassVar[int]
    address: str
    node_address: str
    payment: str
    session_id: int
    staking_reward: str
    subscription_id: int

    def __init__(self, address: _Optional[str]=..., node_address: _Optional[str]=..., payment: _Optional[str]=..., staking_reward: _Optional[str]=..., session_id: _Optional[int]=..., subscription_id: _Optional[int]=...) -> None:
        ...

class EventRefund(_message.Message):
    __slots__ = ['address', 'amount', 'id']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    address: str
    amount: str
    id: int

    def __init__(self, address: _Optional[str]=..., amount: _Optional[str]=..., id: _Optional[int]=...) -> None:
        ...

class EventUpdateStatus(_message.Message):
    __slots__ = ['address', 'id', 'plan_id', 'status']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    PLAN_ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    address: str
    id: int
    plan_id: int
    status: _status_pb2.Status

    def __init__(self, status: _Optional[_Union[(_status_pb2.Status, str)]]=..., address: _Optional[str]=..., id: _Optional[int]=..., plan_id: _Optional[int]=...) -> None:
        ...




from google.protobuf import any_pb2 as _any_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos_proto import cosmos_pb2 as _cosmos_pb2
from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from cosmos.staking.v1beta1 import staking_pb2 as _staking_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class MsgBeginRedelegate(_message.Message):
    __slots__ = ['amount', 'delegator_address', 'validator_dst_address', 'validator_src_address']
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    DELEGATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_DST_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_SRC_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    amount: _coin_pb2.Coin
    delegator_address: str
    validator_dst_address: str
    validator_src_address: str

    def __init__(self, delegator_address: _Optional[str]=..., validator_src_address: _Optional[str]=..., validator_dst_address: _Optional[str]=..., amount: _Optional[_Union[(_coin_pb2.Coin, _Mapping)]]=...) -> None:
        ...

class MsgBeginRedelegateResponse(_message.Message):
    __slots__ = ['completion_time']
    COMPLETION_TIME_FIELD_NUMBER: _ClassVar[int]
    completion_time: _timestamp_pb2.Timestamp

    def __init__(self, completion_time: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=...) -> None:
        ...

class MsgCreateValidator(_message.Message):
    __slots__ = ['commission', 'delegator_address', 'description', 'min_self_delegation', 'pubkey', 'validator_address', 'value']
    COMMISSION_FIELD_NUMBER: _ClassVar[int]
    DELEGATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    MIN_SELF_DELEGATION_FIELD_NUMBER: _ClassVar[int]
    PUBKEY_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    commission: _staking_pb2.CommissionRates
    delegator_address: str
    description: _staking_pb2.Description
    min_self_delegation: str
    pubkey: _any_pb2.Any
    validator_address: str
    value: _coin_pb2.Coin

    def __init__(self, description: _Optional[_Union[(_staking_pb2.Description, _Mapping)]]=..., commission: _Optional[_Union[(_staking_pb2.CommissionRates, _Mapping)]]=..., min_self_delegation: _Optional[str]=..., delegator_address: _Optional[str]=..., validator_address: _Optional[str]=..., pubkey: _Optional[_Union[(_any_pb2.Any, _Mapping)]]=..., value: _Optional[_Union[(_coin_pb2.Coin, _Mapping)]]=...) -> None:
        ...

class MsgCreateValidatorResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class MsgDelegate(_message.Message):
    __slots__ = ['amount', 'delegator_address', 'validator_address']
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    DELEGATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    amount: _coin_pb2.Coin
    delegator_address: str
    validator_address: str

    def __init__(self, delegator_address: _Optional[str]=..., validator_address: _Optional[str]=..., amount: _Optional[_Union[(_coin_pb2.Coin, _Mapping)]]=...) -> None:
        ...

class MsgDelegateResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class MsgEditValidator(_message.Message):
    __slots__ = ['commission_rate', 'description', 'min_self_delegation', 'validator_address']
    COMMISSION_RATE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    MIN_SELF_DELEGATION_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    commission_rate: str
    description: _staking_pb2.Description
    min_self_delegation: str
    validator_address: str

    def __init__(self, description: _Optional[_Union[(_staking_pb2.Description, _Mapping)]]=..., validator_address: _Optional[str]=..., commission_rate: _Optional[str]=..., min_self_delegation: _Optional[str]=...) -> None:
        ...

class MsgEditValidatorResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class MsgUndelegate(_message.Message):
    __slots__ = ['amount', 'delegator_address', 'validator_address']
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    DELEGATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    amount: _coin_pb2.Coin
    delegator_address: str
    validator_address: str

    def __init__(self, delegator_address: _Optional[str]=..., validator_address: _Optional[str]=..., amount: _Optional[_Union[(_coin_pb2.Coin, _Mapping)]]=...) -> None:
        ...

class MsgUndelegateResponse(_message.Message):
    __slots__ = ['completion_time']
    COMPLETION_TIME_FIELD_NUMBER: _ClassVar[int]
    completion_time: _timestamp_pb2.Timestamp

    def __init__(self, completion_time: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ...gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ...tendermint.abci import types_pb2 as tendermint_dot_abci_dot_types__pb2
from ...tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2
from ...tendermint.types import validator_pb2 as tendermint_dot_types_dot_validator__pb2
from ...tendermint.types import params_pb2 as tendermint_dot_types_dot_params__pb2
from ...tendermint.version import types_pb2 as tendermint_dot_version_dot_types__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ctendermint/state/types.proto\x12\x10tendermint.state\x1a\x14gogoproto/gogo.proto\x1a\x1btendermint/abci/types.proto\x1a\x1ctendermint/types/types.proto\x1a tendermint/types/validator.proto\x1a\x1dtendermint/types/params.proto\x1a\x1etendermint/version/types.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\xb8\x01\n\rABCIResponses\x127\n\x0bdeliver_txs\x18\x01 \x03(\x0b2".tendermint.abci.ResponseDeliverTx\x124\n\tend_block\x18\x02 \x01(\x0b2!.tendermint.abci.ResponseEndBlock\x128\n\x0bbegin_block\x18\x03 \x01(\x0b2#.tendermint.abci.ResponseBeginBlock"d\n\x0eValidatorsInfo\x125\n\rvalidator_set\x18\x01 \x01(\x0b2\x1e.tendermint.types.ValidatorSet\x12\x1b\n\x13last_height_changed\x18\x02 \x01(\x03"u\n\x13ConsensusParamsInfo\x12A\n\x10consensus_params\x18\x01 \x01(\x0b2!.tendermint.types.ConsensusParamsB\x04\xc8\xde\x1f\x00\x12\x1b\n\x13last_height_changed\x18\x02 \x01(\x03"S\n\x07Version\x126\n\tconsensus\x18\x01 \x01(\x0b2\x1d.tendermint.version.ConsensusB\x04\xc8\xde\x1f\x00\x12\x10\n\x08software\x18\x02 \x01(\t"\xfd\x04\n\x05State\x120\n\x07version\x18\x01 \x01(\x0b2\x19.tendermint.state.VersionB\x04\xc8\xde\x1f\x00\x12\x1d\n\x08chain_id\x18\x02 \x01(\tB\x0b\xe2\xde\x1f\x07ChainID\x12\x16\n\x0einitial_height\x18\x0e \x01(\x03\x12\x19\n\x11last_block_height\x18\x03 \x01(\x03\x12E\n\rlast_block_id\x18\x04 \x01(\x0b2\x19.tendermint.types.BlockIDB\x13\xc8\xde\x1f\x00\xe2\xde\x1f\x0bLastBlockID\x12=\n\x0flast_block_time\x18\x05 \x01(\x0b2\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x127\n\x0fnext_validators\x18\x06 \x01(\x0b2\x1e.tendermint.types.ValidatorSet\x122\n\nvalidators\x18\x07 \x01(\x0b2\x1e.tendermint.types.ValidatorSet\x127\n\x0flast_validators\x18\x08 \x01(\x0b2\x1e.tendermint.types.ValidatorSet\x12&\n\x1elast_height_validators_changed\x18\t \x01(\x03\x12A\n\x10consensus_params\x18\n \x01(\x0b2!.tendermint.types.ConsensusParamsB\x04\xc8\xde\x1f\x00\x12,\n$last_height_consensus_params_changed\x18\x0b \x01(\x03\x12\x19\n\x11last_results_hash\x18\x0c \x01(\x0c\x12\x10\n\x08app_hash\x18\r \x01(\x0cB9Z7github.com/tendermint/tendermint/proto/tendermint/stateb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.state.types_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z7github.com/tendermint/tendermint/proto/tendermint/state'
    _CONSENSUSPARAMSINFO.fields_by_name['consensus_params']._options = None
    _CONSENSUSPARAMSINFO.fields_by_name['consensus_params']._serialized_options = b'\xc8\xde\x1f\x00'
    _VERSION.fields_by_name['consensus']._options = None
    _VERSION.fields_by_name['consensus']._serialized_options = b'\xc8\xde\x1f\x00'
    _STATE.fields_by_name['version']._options = None
    _STATE.fields_by_name['version']._serialized_options = b'\xc8\xde\x1f\x00'
    _STATE.fields_by_name['chain_id']._options = None
    _STATE.fields_by_name['chain_id']._serialized_options = b'\xe2\xde\x1f\x07ChainID'
    _STATE.fields_by_name['last_block_id']._options = None
    _STATE.fields_by_name['last_block_id']._serialized_options = b'\xc8\xde\x1f\x00\xe2\xde\x1f\x0bLastBlockID'
    _STATE.fields_by_name['last_block_time']._options = None
    _STATE.fields_by_name['last_block_time']._serialized_options = b'\xc8\xde\x1f\x00\x90\xdf\x1f\x01'
    _STATE.fields_by_name['consensus_params']._options = None
    _STATE.fields_by_name['consensus_params']._serialized_options = b'\xc8\xde\x1f\x00'
    _ABCIRESPONSES._serialized_start = 262
    _ABCIRESPONSES._serialized_end = 446
    _VALIDATORSINFO._serialized_start = 448
    _VALIDATORSINFO._serialized_end = 548
    _CONSENSUSPARAMSINFO._serialized_start = 550
    _CONSENSUSPARAMSINFO._serialized_end = 667
    _VERSION._serialized_start = 669
    _VERSION._serialized_end = 752
    _STATE._serialized_start = 755
    _STATE._serialized_end = 1392



import json
import os
import shutil
import time
from os.path import dirname, abspath, isfile, isdir
import fnmatch
import argparse

from git import Repo

parser = argparse.ArgumentParser(description='Aggregate all protobuf files')
parser.add_argument('coin', type=str, help="Coin to parse from the .json file in the config folder")
parser.add_argument('-p', '--package_name', type=str, default="cosmospy_protobuf", help="Name for the package to build. This will aggregate all files in the src/{package_name} folder")
args = parser.parse_args()

# https://stackoverflow.com/questions/52071642/python-copying-the-files-with-include-pattern
def include_patterns(*patterns):
    def _ignore_patterns(path, names):
        keep = set(name for pattern in patterns
                   for name in fnmatch.filter(names, pattern))
        ignore = set(name for name in names
                     if name not in keep and not isdir(os.path.join(path, name)))
        return ignore

    return _ignore_patterns
# Get current directory
d = dirname(abspath(__file__))

# Check if requested coin has a config
coin = args.coin
try:
    config_path = os.path.join(d, f'configs/{coin.lower()}.json')
    f = open(config_path, "r")
    coin_config = json.load(f)
    f.close()
except Exception:
    print("Coin couldn't be found")
    exit()


tmp_dir = os.path.join(d, "tmp")
if not os.path.isdir(tmp_dir):
    os.mkdir(tmp_dir)

project_dir = os.path.join(tmp_dir, str(time.time()))
os.mkdir(project_dir)

# Delete all existing protobuf files
root_dir = "src/" + args.package_name
root_abs_path = os.path.join(d, root_dir)
os.makedirs(root_abs_path, exist_ok=True)  # Create folder for package

for filename in os.listdir(root_abs_path):
    if filename == ".gitignore":
        continue

    file_path = os.path.join(root_abs_path, filename)
    try:
        if os.path.isfile(file_path) or os.path.islink(file_path):
            os.unlink(file_path)
        elif os.path.isdir(file_path):
            shutil.rmtree(file_path)
    except Exception as e:
        print('Failed to delete %s. Reason: %s' % (file_path, e))

# Load config
i = 1
for repo_url, repo_config in coin_config.items():
    print(f"Cloning {repo_url} | {repo_config['branch']}")
    repo_dir = project_dir + "/" + str(i)
    Repo.clone_from(
        repo_url,
        project_dir + "/" + str(i),
        branch=repo_config['branch']
    )

    # Copy proto files to root_dir
    for proto_folder in repo_config['paths']:
        proto_dir = os.path.join(repo_dir, proto_folder)
        proto_path_list = proto_folder.split('/')
        target = repo_config["target"] + "/" if "target" in repo_config else ""

        # If the path consists of 2 or less consider the latest entry to be the according path
        if len(proto_path_list) <= 2:
            proto_path_in_repo = proto_path_list[-1]
        else: # If the path has more than 2 items remove the first one and take the rest
            proto_path_list.pop(0)
            proto_path_in_repo = "/".join(proto_path_list)

        # Fix compiling for Google protobuf
        if proto_path_in_repo == 'proto/google':
            proto_path_in_repo = proto_path_in_repo.split('/')[1]

        try:
            shutil.copytree(proto_dir, root_abs_path + "/" + (target if target else proto_path_in_repo), dirs_exist_ok=True, ignore=include_patterns("*.proto"))
            print(f"Copied {proto_path_in_repo}")
        except OSError as exc:
            try:
                proto_path_in_repo_for_file = target if target else "/".join(proto_path_in_repo.split('/')[:-1])# Remove file from path ending to be compatible with the folder creation and copy path
                os.makedirs(os.path.dirname(root_abs_path + "/" +  proto_path_in_repo_for_file), exist_ok=True) # Create folder for file
                shutil.copy(proto_dir, root_abs_path + "/" + proto_path_in_repo_for_file  )
                print(f"File {proto_dir} copied successfully")
            except:
                raise

    i += 1







'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from ....cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fcosmos/bank/v1beta1/authz.proto\x12\x13cosmos.bank.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19cosmos_proto/cosmos.proto\x1a\x1ecosmos/base/v1beta1/coin.proto"\x88\x01\n\x11SendAuthorization\x12`\n\x0bspend_limit\x18\x01 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:\x11\xca\xb4-\rAuthorizationB+Z)github.com/cosmos/cosmos-sdk/x/bank/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.bank.v1beta1.authz_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/bank/types'
    _SENDAUTHORIZATION.fields_by_name['spend_limit']._options = None
    _SENDAUTHORIZATION.fields_by_name['spend_limit']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins'
    _SENDAUTHORIZATION._options = None
    _SENDAUTHORIZATION._serialized_options = b'\xca\xb4-\rAuthorization'
    _SENDAUTHORIZATION._serialized_start = 138
    _SENDAUTHORIZATION._serialized_end = 274




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ...gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ...tendermint.crypto import keys_pb2 as tendermint_dot_crypto_dot_keys__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19tendermint/p2p/conn.proto\x12\x0etendermint.p2p\x1a\x14gogoproto/gogo.proto\x1a\x1ctendermint/crypto/keys.proto"\x0c\n\nPacketPing"\x0c\n\nPacketPong"R\n\tPacketMsg\x12!\n\nchannel_id\x18\x01 \x01(\x05B\r\xe2\xde\x1f\tChannelID\x12\x14\n\x03eof\x18\x02 \x01(\x08B\x07\xe2\xde\x1f\x03EOF\x12\x0c\n\x04data\x18\x03 \x01(\x0c"\xa6\x01\n\x06Packet\x121\n\x0bpacket_ping\x18\x01 \x01(\x0b2\x1a.tendermint.p2p.PacketPingH\x00\x121\n\x0bpacket_pong\x18\x02 \x01(\x0b2\x1a.tendermint.p2p.PacketPongH\x00\x12/\n\npacket_msg\x18\x03 \x01(\x0b2\x19.tendermint.p2p.PacketMsgH\x00B\x05\n\x03sum"R\n\x0eAuthSigMessage\x123\n\x07pub_key\x18\x01 \x01(\x0b2\x1c.tendermint.crypto.PublicKeyB\x04\xc8\xde\x1f\x00\x12\x0b\n\x03sig\x18\x02 \x01(\x0cB7Z5github.com/tendermint/tendermint/proto/tendermint/p2pb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.p2p.conn_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z5github.com/tendermint/tendermint/proto/tendermint/p2p'
    _PACKETMSG.fields_by_name['channel_id']._options = None
    _PACKETMSG.fields_by_name['channel_id']._serialized_options = b'\xe2\xde\x1f\tChannelID'
    _PACKETMSG.fields_by_name['eof']._options = None
    _PACKETMSG.fields_by_name['eof']._serialized_options = b'\xe2\xde\x1f\x03EOF'
    _AUTHSIGMESSAGE.fields_by_name['pub_key']._options = None
    _AUTHSIGMESSAGE.fields_by_name['pub_key']._serialized_options = b'\xc8\xde\x1f\x00'
    _PACKETPING._serialized_start = 97
    _PACKETPING._serialized_end = 109
    _PACKETPONG._serialized_start = 111
    _PACKETPONG._serialized_end = 123
    _PACKETMSG._serialized_start = 125
    _PACKETMSG._serialized_end = 207
    _PACKET._serialized_start = 210
    _PACKET._serialized_end = 376
    _AUTHSIGMESSAGE._serialized_start = 378
    _AUTHSIGMESSAGE._serialized_end = 460




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from ....cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ecosmos/bank/v1beta1/bank.proto\x12\x13cosmos.bank.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19cosmos_proto/cosmos.proto\x1a\x1ecosmos/base/v1beta1/coin.proto"\xb2\x01\n\x06Params\x12Y\n\x0csend_enabled\x18\x01 \x03(\x0b2 .cosmos.bank.v1beta1.SendEnabledB!\xf2\xde\x1f\x1dyaml:"send_enabled,omitempty"\x12G\n\x14default_send_enabled\x18\x02 \x01(\x08B)\xf2\xde\x1f%yaml:"default_send_enabled,omitempty":\x04\x98\xa0\x1f\x00"7\n\x0bSendEnabled\x12\r\n\x05denom\x18\x01 \x01(\t\x12\x0f\n\x07enabled\x18\x02 \x01(\x08:\x08\xe8\xa0\x1f\x01\x98\xa0\x1f\x00"~\n\x05Input\x12\x0f\n\x07address\x18\x01 \x01(\t\x12Z\n\x05coins\x18\x02 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\x7f\n\x06Output\x12\x0f\n\x07address\x18\x01 \x01(\t\x12Z\n\x05coins\x18\x02 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\xac\x01\n\x06Supply\x12Z\n\x05total\x18\x01 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:F\x18\x01\xe8\xa0\x1f\x01\x88\xa0\x1f\x00\xca\xb4-8*github.com/cosmos/cosmos-sdk/x/bank/legacy/v040.SupplyI"=\n\tDenomUnit\x12\r\n\x05denom\x18\x01 \x01(\t\x12\x10\n\x08exponent\x18\x02 \x01(\r\x12\x0f\n\x07aliases\x18\x03 \x03(\t"\x91\x01\n\x08Metadata\x12\x13\n\x0bdescription\x18\x01 \x01(\t\x123\n\x0bdenom_units\x18\x02 \x03(\x0b2\x1e.cosmos.bank.v1beta1.DenomUnit\x12\x0c\n\x04base\x18\x03 \x01(\t\x12\x0f\n\x07display\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0e\n\x06symbol\x18\x06 \x01(\tB+Z)github.com/cosmos/cosmos-sdk/x/bank/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.bank.v1beta1.bank_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/bank/types'
    _PARAMS.fields_by_name['send_enabled']._options = None
    _PARAMS.fields_by_name['send_enabled']._serialized_options = b'\xf2\xde\x1f\x1dyaml:"send_enabled,omitempty"'
    _PARAMS.fields_by_name['default_send_enabled']._options = None
    _PARAMS.fields_by_name['default_send_enabled']._serialized_options = b'\xf2\xde\x1f%yaml:"default_send_enabled,omitempty"'
    _PARAMS._options = None
    _PARAMS._serialized_options = b'\x98\xa0\x1f\x00'
    _SENDENABLED._options = None
    _SENDENABLED._serialized_options = b'\xe8\xa0\x1f\x01\x98\xa0\x1f\x00'
    _INPUT.fields_by_name['coins']._options = None
    _INPUT.fields_by_name['coins']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins'
    _INPUT._options = None
    _INPUT._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _OUTPUT.fields_by_name['coins']._options = None
    _OUTPUT.fields_by_name['coins']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins'
    _OUTPUT._options = None
    _OUTPUT._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _SUPPLY.fields_by_name['total']._options = None
    _SUPPLY.fields_by_name['total']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins'
    _SUPPLY._options = None
    _SUPPLY._serialized_options = b'\x18\x01\xe8\xa0\x1f\x01\x88\xa0\x1f\x00\xca\xb4-8*github.com/cosmos/cosmos-sdk/x/bank/legacy/v040.SupplyI'
    _PARAMS._serialized_start = 137
    _PARAMS._serialized_end = 315
    _SENDENABLED._serialized_start = 317
    _SENDENABLED._serialized_end = 372
    _INPUT._serialized_start = 374
    _INPUT._serialized_end = 500
    _OUTPUT._serialized_start = 502
    _OUTPUT._serialized_end = 629
    _SUPPLY._serialized_start = 632
    _SUPPLY._serialized_end = 804
    _DENOMUNIT._serialized_start = 806
    _DENOMUNIT._serialized_end = 867
    _METADATA._serialized_start = 870
    _METADATA._serialized_end = 1015




from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos_proto import cosmos_pb2 as _cosmos_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import any_pb2 as _any_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor
PROPOSAL_STATUS_DEPOSIT_PERIOD: ProposalStatus
PROPOSAL_STATUS_FAILED: ProposalStatus
PROPOSAL_STATUS_PASSED: ProposalStatus
PROPOSAL_STATUS_REJECTED: ProposalStatus
PROPOSAL_STATUS_UNSPECIFIED: ProposalStatus
PROPOSAL_STATUS_VOTING_PERIOD: ProposalStatus
VOTE_OPTION_ABSTAIN: VoteOption
VOTE_OPTION_NO: VoteOption
VOTE_OPTION_NO_WITH_VETO: VoteOption
VOTE_OPTION_UNSPECIFIED: VoteOption
VOTE_OPTION_YES: VoteOption

class Deposit(_message.Message):
    __slots__ = ['amount', 'depositor', 'proposal_id']
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    DEPOSITOR_FIELD_NUMBER: _ClassVar[int]
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    amount: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    depositor: str
    proposal_id: int

    def __init__(self, proposal_id: _Optional[int]=..., depositor: _Optional[str]=..., amount: _Optional[_Iterable[_Union[(_coin_pb2.Coin, _Mapping)]]]=...) -> None:
        ...

class DepositParams(_message.Message):
    __slots__ = ['max_deposit_period', 'min_deposit']
    MAX_DEPOSIT_PERIOD_FIELD_NUMBER: _ClassVar[int]
    MIN_DEPOSIT_FIELD_NUMBER: _ClassVar[int]
    max_deposit_period: _duration_pb2.Duration
    min_deposit: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]

    def __init__(self, min_deposit: _Optional[_Iterable[_Union[(_coin_pb2.Coin, _Mapping)]]]=..., max_deposit_period: _Optional[_Union[(_duration_pb2.Duration, _Mapping)]]=...) -> None:
        ...

class Proposal(_message.Message):
    __slots__ = ['content', 'deposit_end_time', 'final_tally_result', 'proposal_id', 'status', 'submit_time', 'total_deposit', 'voting_end_time', 'voting_start_time']
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    DEPOSIT_END_TIME_FIELD_NUMBER: _ClassVar[int]
    FINAL_TALLY_RESULT_FIELD_NUMBER: _ClassVar[int]
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    SUBMIT_TIME_FIELD_NUMBER: _ClassVar[int]
    TOTAL_DEPOSIT_FIELD_NUMBER: _ClassVar[int]
    VOTING_END_TIME_FIELD_NUMBER: _ClassVar[int]
    VOTING_START_TIME_FIELD_NUMBER: _ClassVar[int]
    content: _any_pb2.Any
    deposit_end_time: _timestamp_pb2.Timestamp
    final_tally_result: TallyResult
    proposal_id: int
    status: ProposalStatus
    submit_time: _timestamp_pb2.Timestamp
    total_deposit: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    voting_end_time: _timestamp_pb2.Timestamp
    voting_start_time: _timestamp_pb2.Timestamp

    def __init__(self, proposal_id: _Optional[int]=..., content: _Optional[_Union[(_any_pb2.Any, _Mapping)]]=..., status: _Optional[_Union[(ProposalStatus, str)]]=..., final_tally_result: _Optional[_Union[(TallyResult, _Mapping)]]=..., submit_time: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=..., deposit_end_time: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=..., total_deposit: _Optional[_Iterable[_Union[(_coin_pb2.Coin, _Mapping)]]]=..., voting_start_time: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=..., voting_end_time: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=...) -> None:
        ...

class TallyParams(_message.Message):
    __slots__ = ['quorum', 'threshold', 'veto_threshold']
    QUORUM_FIELD_NUMBER: _ClassVar[int]
    THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    VETO_THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    quorum: bytes
    threshold: bytes
    veto_threshold: bytes

    def __init__(self, quorum: _Optional[bytes]=..., threshold: _Optional[bytes]=..., veto_threshold: _Optional[bytes]=...) -> None:
        ...

class TallyResult(_message.Message):
    __slots__ = ['abstain', 'no', 'no_with_veto', 'yes']
    ABSTAIN_FIELD_NUMBER: _ClassVar[int]
    NO_FIELD_NUMBER: _ClassVar[int]
    NO_WITH_VETO_FIELD_NUMBER: _ClassVar[int]
    YES_FIELD_NUMBER: _ClassVar[int]
    abstain: str
    no: str
    no_with_veto: str
    yes: str

    def __init__(self, yes: _Optional[str]=..., abstain: _Optional[str]=..., no: _Optional[str]=..., no_with_veto: _Optional[str]=...) -> None:
        ...

class TextProposal(_message.Message):
    __slots__ = ['description', 'title']
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    description: str
    title: str

    def __init__(self, title: _Optional[str]=..., description: _Optional[str]=...) -> None:
        ...

class Vote(_message.Message):
    __slots__ = ['option', 'options', 'proposal_id', 'voter']
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    OPTION_FIELD_NUMBER: _ClassVar[int]
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    VOTER_FIELD_NUMBER: _ClassVar[int]
    option: VoteOption
    options: _containers.RepeatedCompositeFieldContainer[WeightedVoteOption]
    proposal_id: int
    voter: str

    def __init__(self, proposal_id: _Optional[int]=..., voter: _Optional[str]=..., option: _Optional[_Union[(VoteOption, str)]]=..., options: _Optional[_Iterable[_Union[(WeightedVoteOption, _Mapping)]]]=...) -> None:
        ...

class VotingParams(_message.Message):
    __slots__ = ['voting_period']
    VOTING_PERIOD_FIELD_NUMBER: _ClassVar[int]
    voting_period: _duration_pb2.Duration

    def __init__(self, voting_period: _Optional[_Union[(_duration_pb2.Duration, _Mapping)]]=...) -> None:
        ...

class WeightedVoteOption(_message.Message):
    __slots__ = ['option', 'weight']
    OPTION_FIELD_NUMBER: _ClassVar[int]
    WEIGHT_FIELD_NUMBER: _ClassVar[int]
    option: VoteOption
    weight: str

    def __init__(self, option: _Optional[_Union[(VoteOption, str)]]=..., weight: _Optional[str]=...) -> None:
        ...

class VoteOption(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class ProposalStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ...gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dtendermint/crypto/proof.proto\x12\x11tendermint.crypto\x1a\x14gogoproto/gogo.proto"G\n\x05Proof\x12\r\n\x05total\x18\x01 \x01(\x03\x12\r\n\x05index\x18\x02 \x01(\x03\x12\x11\n\tleaf_hash\x18\x03 \x01(\x0c\x12\r\n\x05aunts\x18\x04 \x03(\x0c"?\n\x07ValueOp\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\'\n\x05proof\x18\x02 \x01(\x0b2\x18.tendermint.crypto.Proof"6\n\x08DominoOp\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05input\x18\x02 \x01(\t\x12\x0e\n\x06output\x18\x03 \x01(\t"2\n\x07ProofOp\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\x0c\x12\x0c\n\x04data\x18\x03 \x01(\x0c"9\n\x08ProofOps\x12-\n\x03ops\x18\x01 \x03(\x0b2\x1a.tendermint.crypto.ProofOpB\x04\xc8\xde\x1f\x00B:Z8github.com/tendermint/tendermint/proto/tendermint/cryptob\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.crypto.proof_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z8github.com/tendermint/tendermint/proto/tendermint/crypto'
    _PROOFOPS.fields_by_name['ops']._options = None
    _PROOFOPS.fields_by_name['ops']._serialized_options = b'\xc8\xde\x1f\x00'
    _PROOF._serialized_start = 74
    _PROOF._serialized_end = 145
    _VALUEOP._serialized_start = 147
    _VALUEOP._serialized_end = 210
    _DOMINOOP._serialized_start = 212
    _DOMINOOP._serialized_end = 266
    _PROOFOP._serialized_start = 268
    _PROOFOP._serialized_end = 318
    _PROOFOPS._serialized_start = 320
    _PROOFOPS._serialized_end = 377




from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional
DESCRIPTOR: _descriptor.FileDescriptor

class BitArray(_message.Message):
    __slots__ = ['bits', 'elems']
    BITS_FIELD_NUMBER: _ClassVar[int]
    ELEMS_FIELD_NUMBER: _ClassVar[int]
    bits: int
    elems: _containers.RepeatedScalarFieldContainer[int]

    def __init__(self, bits: _Optional[int]=..., elems: _Optional[_Iterable[int]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ......gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7ibc/applications/interchain_accounts/host/v1/host.proto\x12,ibc.applications.interchain_accounts.host.v1\x1a\x14gogoproto/gogo.proto"j\n\x06Params\x12-\n\x0chost_enabled\x18\x01 \x01(\x08B\x17\xf2\xde\x1f\x13yaml:"host_enabled"\x121\n\x0eallow_messages\x18\x02 \x03(\tB\x19\xf2\xde\x1f\x15yaml:"allow_messages"BLZJgithub.com/cosmos/ibc-go/v3/modules/apps/27-interchain-accounts/host/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.interchain_accounts.host.v1.host_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'ZJgithub.com/cosmos/ibc-go/v3/modules/apps/27-interchain-accounts/host/types'
    _PARAMS.fields_by_name['host_enabled']._options = None
    _PARAMS.fields_by_name['host_enabled']._serialized_options = b'\xf2\xde\x1f\x13yaml:"host_enabled"'
    _PARAMS.fields_by_name['allow_messages']._options = None
    _PARAMS.fields_by_name['allow_messages']._serialized_options = b'\xf2\xde\x1f\x15yaml:"allow_messages"'
    _PARAMS._serialized_start = 127
    _PARAMS._serialized_end = 233
